/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CHAFFVERB_H_
#define _HEAVY_CHAFFVERB_H_

#include "HvHeavy.h"

#ifdef __cplusplus
extern "C" {
#endif

#if HV_APPLE
#pragma mark - Heavy Context
#endif

typedef enum {
  HV_CHAFFVERB_PARAM_IN_A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
  HV_CHAFFVERB_PARAM_IN_A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
  HV_CHAFFVERB_PARAM_IN_A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
  HV_CHAFFVERB_PARAM_IN_A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
  HV_CHAFFVERB_PARAM_IN_A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
  HV_CHAFFVERB_PARAM_IN_B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
  HV_CHAFFVERB_PARAM_IN_B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
  HV_CHAFFVERB_PARAM_IN_C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
  HV_CHAFFVERB_PARAM_IN_C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
  HV_CHAFFVERB_PARAM_IN_C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
  HV_CHAFFVERB_PARAM_IN_C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
  HV_CHAFFVERB_PARAM_IN_D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
  HV_CHAFFVERB_PARAM_IN_D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
  HV_CHAFFVERB_PARAM_IN_E__FX_LEVEL = 0x890283C2, // E__Fx_Level
  HV_CHAFFVERB_PARAM_IN_E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
  HV_CHAFFVERB_PARAM_IN_E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
  HV_CHAFFVERB_PARAM_IN_E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
  HV_CHAFFVERB_PARAM_IN_F__FX_DELAY = 0x69A91334, // F__FX_Delay
  HV_CHAFFVERB_PARAM_IN_F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
  HV_CHAFFVERB_PARAM_IN_MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
  HV_CHAFFVERB_PARAM_IN_MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
  HV_CHAFFVERB_PARAM_IN_MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
  HV_CHAFFVERB_PARAM_IN_MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
} Hv_ChaffVerb_ParameterIn;


/**
 * Creates a new patch instance.
 * Sample rate should be positive and in Hertz, e.g. 44100.0.
 */
HeavyContextInterface *hv_ChaffVerb_new(double sampleRate);

/**
 * Creates a new patch instance.
 * @param sampleRate  Sample rate should be positive (> 0) and in Hertz, e.g. 48000.0.
 * @param poolKb  Pool size is in kilobytes, and determines the maximum amount of memory
 *   allocated to messages at any time. By default this is 10 KB.
 * @param inQueueKb  The size of the input message queue in kilobytes. It determines the
 *   amount of memory dedicated to holding scheduled messages between calls to
 *   process(). Default is 2 KB.
 * @param outQueueKb  The size of the output message queue in kilobytes. It determines the
 *   amount of memory dedicated to holding scheduled messages to the default sendHook.
 *   See getNextSentMessage() for info on accessing these messages. Default is 0 KB.
 */
HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate, int poolKb, int inQueueKb, int outQueueKb);

/**
 * Free the patch instance.
 */
void hv_ChaffVerb_free(HeavyContextInterface *instance);


#ifdef __cplusplus
} // extern "C"
#endif

#endif // _HEAVY_CHAFFVERB_H_
