/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlDelay.h"
#include "HvControlRandom.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvControlCast.h"
#include "HvTable.h"
#include "HvSignalVar.h"
#include "HvControlSystem.h"
#include "HvControlTabhead.h"
#include "HvSignalDel1.h"
#include "HvControlIf.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvSignalTabwrite.h"
#include "HvSignalTabread.h"
#include "HvControlSlice.h"
#include "HvControlPack.h"
#include "HvSignalPhasor.h"
#include "HvSignalRPole.h"
#include "HvControlVar.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_UWMMT0e2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CNGTiPGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_o5HaKavT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xMNgVWee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dto9N145_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_041uOvaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_KyIvik6c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PzCwzUWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qjD4She6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oZSr7Hb6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qsHKyMEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PQrPsnNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kLCpSjFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zMsmAeVP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_BiXzhzMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5RlnjNqp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rM8RXP58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gpawZNsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EUY0HAAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eXmPuBGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ddimt9OH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xY9XhAdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jNN6ubuS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4lNLt9oP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QyLFhk7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oRPSlwp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lL6PuBRh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T9EVgGTq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z4VP5Fd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qSD6jZ09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_04EA2d7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sxHvW3Pk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_d3oQswTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iF6z6W7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aRfU7Jx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sHyeSlZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i1JxzCSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zrs8R9NH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MH22F9SL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I98ZqBUh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9eYTy4tA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NNseNfMN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHusmIMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ccVKv0bf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p5uSI42P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DO3V3mTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_b6vx3HyZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_Iyp7cWZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VPdtjXQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JmSqiTAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_acbvDvP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E7aSCMRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZhRtlPuk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7A6SB9av_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_faOmb4Xe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zw2g1GuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PMGQVlVS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OFIYybSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fwYbdoCH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DI3L2GLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xND2xEe8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T6xplnIO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lm58JNs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4mvOr2Ug_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_98EhcLQC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0GITFccM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_henzVE9I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_9cVvqcQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SeI6HxYr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_zXjXv8ut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0imByWwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yiOritOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WjMk9LLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U9g3Nsw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xy8PGSrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M4TlyE7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GWsYAMm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HbnYuEk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_EnArtQpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pVy2P2Uf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_deCWU9ZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HkjIulP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LRQzYMw9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uJMexdf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_PDe0HwNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sSC8oqap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qEYDC89C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1FXRvxYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6oybqGk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7rjx08BG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jGVxBwDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NlcBv8Ke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jE7aAKuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0B3Nopad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4fMBZ0Q9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E7J2RT6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I7UnMYKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_RGUU2kwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_86xi66Xw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_M7ji9KlC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SHypic6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4XVpyPnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3UqkrnUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_IzrpiWte_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hGO85G7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZTxEIaWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e47BMWTP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dKQMqXRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u4wuJboI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U5jdyOZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FPFmKDaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5cz2krqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PtXT00lY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BOwfUEBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iL0njLex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VLGA3Y6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_wx7xKHdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uvmjNcu1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_45e3AZyT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F5FHf6gp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TzyFyHg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EQQXwJ0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_qc2b87oB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jeW0Y2Li_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vjTrvljM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4zg4JbE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_786hsxnO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z8RD8CoU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jCGEMSeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EcdDd8Bd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A1NYb0cm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TvqKpzmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DUuEXQJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GkeppHox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_12O3sDim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_7ca0893V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rFfu09ED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PF0yMMN7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_60d20ORg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FHWwSQnS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SuESw1Mg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_N8FJrk2P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6J9HYGEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xqvMPPeD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_em9JdRrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SOnWiJDF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VQtqKiNL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VhNvCswW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IjtQSA3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IeMFij0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JWWHzN7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6U3fNJ4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QTzzxmG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0pncQUGO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yCZswnsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LoLPI6jy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4ycZzfj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WgZYbQEF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_drM2UA2x_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_0b74NO31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_wPdczNpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_okFitmns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OMcuQlUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kF0mRabj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FqCuXZF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fClDRAC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8GPX3Gxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DfdQmBkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zbCZpUpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rAaXvMc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1CzzuPvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mODoxFhV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_DPBJTSJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5A2r9Zyx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A0xnXgHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gq1Ja6Sz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_69Lw4Z57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RJnJdpYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tjgKFnLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TXmhoUCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RztTIQCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Nz9Ago7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_502lqRWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MHYfMRRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pP83l3Yj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_KX35phux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TKbRAdvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i54AzSFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6AaX4dmd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NdKcC07g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VxQVajnA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9uT7zqSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YX1SOjOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aNWGerEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7x8mQgiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hN8EeENw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_jVxaXvU0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CSuQ8xFJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_hnReGYTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_7YuvHw7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uSLF1vGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TwYwm2eP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q8K9L7hW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1vFpnTZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_al8YuVpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QcyBETQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_K4PnQdXQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_3YqwzeYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zvL0pmQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ev2ShP6O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HSlGCHA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4TgKCkTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vTRbwWhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EMt4Vyzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qJBNjWFz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yVv2TF1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vOzzieBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z2fqK4pv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b6qMY8ba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F9qBmmsd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AHOszjdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7r6dzwHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LKCycrEt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_poHZtvEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MHH8fvZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uOTpqZ4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k9Tqh78W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F4hXZaeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YSu9pFWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0gXpYMnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gHlhYlC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pH5nSwkS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_wx6bMVdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_tNSn6Vtl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8M490MLI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ntGDMCz5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4x3U3L9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P8AnIZy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lwCBd2F2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uo19bEj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_aknAYwMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zEaDoJap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YFocQdfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EefoUigE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zxS67NUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bvprG8Eq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_md9W2lHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HnCpE2GK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FJ8u6v79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cshdMLNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pGK9kJfV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4OI6NN2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x97nqSUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B8Or1WnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RBcDn6UE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5egw6d0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WJPMFlFB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HKzwwybt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l2o3cZTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zfSubXr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xHuUEkXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7D0NBdb5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9CqeH8rM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dQFDMpU0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_7TucOsZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_MGugfUR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SeyC9v8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4s1WmBgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JPR9LaQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VR4d3dEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ebYX0oAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sn52Ei64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_iXy9DCvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1ddP1Vy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VOQLUouz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zlj8FHVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h6IeY1oP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tY4ccei7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_frKbON3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AtQLUW4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dvt3jHd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WNRhtGXf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gfYY7BGX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BLzCNKyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MMwRTkq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FS1Hwuk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3s4DzZnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_usJd83vV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QHSaXxp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MmSlofXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9zsN1J3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O26RDPFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JkjeJjpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VbLDURlZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wfw4TEHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ikisInRg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Odz65GT9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_emDYDVwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fanAAlZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1bbqz5VD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_weo6ZaCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nUrq9xX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F2oLu150_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AfixM86g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_m6Etjp1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vLMuInHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zPYmNGED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mqBwZ7gx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3Ips83n2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Cpfn0VK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_EogYwzgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V98jRqTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_St1CHJh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9lyRiT9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gWNePGPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uFIqXYGh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kv4fnzDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xSdVqRAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Q1TFB9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WUNmEWHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wgzYdmkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uG25ajUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NBJ7qSHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZZZmZZ2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_t5tHTRb5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eM3xHo9F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4uJeTEIz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SZDbsAQ0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_cqMmf0bl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5tQbL0kn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0eBWagvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xUhMG1Lr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MMffPAYZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hGqFJSgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YuBem4qu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZL4ghQ2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_hL9s3z62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nAC5PKiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Rpw3YgyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iegFFako_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_U7gXAZEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_na2rL4o7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_1ApzqGAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J6KpcyON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vRRImeS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ku0MLZy6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wIQDrjBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pIG7ycJG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fWPjFt1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HgueDCvu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TMC0sOHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6a8Ltsax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_55ZChlxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XEFBhMPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d6bKAyHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BFd7qWMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9UpJzTrZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RdQEwcJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Wr1XIBPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0CfeYwwv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_K1v0ye0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Avz2hLQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f67ftqZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F6eU2Kuk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KpStpZc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7UAJHV25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JPpAz5ns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c8JZ4Jg5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Z8WE4sfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zkrcGe5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3LMv8HP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bRO7vB3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HT85cYWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oeZCRwUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_rY7yVUSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lchHwaKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aqX9O9Bk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ET00avC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_COxlzzqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cSSIFoYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_71SLFi9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rp37ym7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZHossFJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jnaj2agm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dQFdoT6s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QJwEZ21f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8AvnEmYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lETNTkFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5wTRpiCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5EeaIJNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AKCvJFlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bHqc6YaO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_oFj8SUsR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ToCIyopm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j427yxXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u6ETI3su_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UgA0KcTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gj29PWes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xLCbKBLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ibQV0lLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_6nDh6N0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s9HpVawm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VM5vfdZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_83kHpFj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DkySWy7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3w7hwfiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_mYYZ7gvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Lk5ozKv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9GUWdxxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FxaFlwTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kOXEPXru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wMpaenIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HMefA8e1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nS95ZjQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z285CSYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CsIFeJJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GpKJyUM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RyMypoWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HR7iuo9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_POKssBKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eeqrJpuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_GlVwqoqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GbTlsh7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lTdcDZTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_u5GBZJh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yYxWUfBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JmNGUXqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XB5bCoTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s5BMpUzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DcVswJyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20NlDdF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fVuXzs52_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pK6MLld1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HTBzZRha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8TIHPuUU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nQzUBpC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2pSuOpTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qiarUK0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XtsuzYDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pqKoES14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UHz1HLls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L3N5OAZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jqf78rET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5nCwwhn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RiYX2VrP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8h0xV5yG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sq5sfbGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dIFSLBHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_upHUBXAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m1KgPrbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_exKKrtmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFFN2IkJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sc6FT59X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kmq3hgdi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_QyU9T2L3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pFdMtrCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zIsnKIAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_X7TePXAu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5FSPIk4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SZ1KK6GO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wNHUks45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qSJCm20t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IduixJ1G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WHXQ45N1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DG3Qnaw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_chW1nKqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_H5yAW1gJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yBSky8vu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jkcx0EbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zmA9EANP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xpdx8RwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MtFC3sg4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Ib7httWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_L9cXkt2P_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_7J3uBwSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_1XjpSzeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_imYs6cKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mKvqHyNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dhr8hoDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LMtuij71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E2d9hPG4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_twgWlZmM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_sX1yC4Yi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m0owYjol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2A4ZB5iW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Mf8ghVRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wokSF4Wl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PZkDYgok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Lx5Bs3di_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uzE64LDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tGt9XMi8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fAeIc8ls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wBVd5YL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UmaOLvmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YaJ2pa5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EjYnU63C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SLTP6G7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HpZJYeU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gsy6J4bQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GMatwuuu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bc7uyE7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VjLpngWL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_gn3ROFWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XT5xndzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xVieuHoW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_P9IL8cuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bvxNzdgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TE6yMAFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UmJpRQmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fLJ1G8Dn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qeIAI8zw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ttj0nwVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_agyefumz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_n5bkwcMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FnKuJIBK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VYz93BPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jgnp9dSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_C8GZyRpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A2RTTro3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4VxPk6DZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SY1o8nP3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XBoxBlK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_PfMGu1wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7QnUSpqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_X40IJkea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VtIECSFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PZ3dOUOu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zG3kG6ph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GVvY0EOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_avc8ujFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fJYHQjYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9wriYu8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vkCQZ1rg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hX6bEGqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1jxL0xft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZCfKQ4v6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0EYrv1rN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dNewLAvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e4C2itZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B0Xmw2qN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tH07Ncba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iljG9mZr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YObEr6Bo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YyON3lLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nWjUTx6P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_htC4fmL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hdGo7jCx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bZJTyyXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lnURvqF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VJMKVXyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KZS9HhG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CPBSaMbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8pmQVdbu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KkFLowWC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TOxUo8qB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JnKyS8iI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SNgSt2KJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hVA6EyMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4pFQ3Cfh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GuTABrHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A4Zz6XDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jaxSsEro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3AVeJRA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VltMNnFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FyUZw0Oq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WtN5oQc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oJx852qo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bS1pKTow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sWglARYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TaN0frUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kffdjamT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YZ65ZF4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OiQZpP4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rGQcI1AT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dh9ifyfo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jjCntwxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CFlBZ133_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JTuEwNP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KLEv1yVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V9OrX3Zk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vBrDNjDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ro4ekVBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T6Jr708P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vmRG0h4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EllY8nDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AFW90A92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_91lhiHbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qXdky84I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WRiik0Nw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1LVkPoXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6XGFo1Kh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ECxQXQ5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_J0hSlsEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yUxrBDcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gp8Ta2RC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uYvPOAq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5ZpXWD4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Bux2lCNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2KegU7qJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sG45Gr5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QnS0u8yf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aYN5EBXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_edWEiymq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0E3gQzdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9xfmKe1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_dzgHu6BW;
  SignalLine sLine_hUAIaXYQ;
  SignalLine sLine_rvsqBg5L;
  SignalTabhead sTabhead_palhez3K;
  SignalTabread sTabread_1vUeBqrD;
  SignalTabread sTabread_xXLWRIvO;
  SignalTabhead sTabhead_bmEa0HnT;
  SignalTabread sTabread_cYpoUHYw;
  SignalTabread sTabread_fcyAYF4R;
  SignalTabwrite sTabwrite_WTuF4Gkk;
  SignalRPole sRPole_wYz5cVrI;
  SignalDel1 sDel1_EdfxeXAJ;
  SignalTabread sTabread_Lx5Bs3di;
  SignalTabwrite sTabwrite_1vQ6VjNe;
  SignalTabread sTabread_PDe0HwNj;
  SignalRPole sRPole_pfJJGFwL;
  SignalLine sLine_1a7Hv02L;
  SignalLine sLine_Ezfv51Su;
  SignalTabread sTabread_md9W2lHD;
  SignalTabread sTabread_frKbON3F;
  SignalTabread sTabread_EogYwzgO;
  SignalTabread sTabread_1ApzqGAn;
  SignalTabread sTabread_mYYZ7gvP;
  SignalTabread sTabread_rY7yVUSK;
  SignalTabwrite sTabwrite_IaUKLhF8;
  SignalTabwrite sTabwrite_uJNO9xsm;
  SignalTabwrite sTabwrite_fOjMITgU;
  SignalTabwrite sTabwrite_WuoAJjGa;
  SignalTabwrite sTabwrite_2yXCFzXM;
  SignalTabwrite sTabwrite_E5r8nFey;
  SignalTabread sTabread_IzrpiWte;
  SignalRPole sRPole_hvV9Sj9O;
  SignalTabread sTabread_qc2b87oB;
  SignalRPole sRPole_sjpdBdLw;
  SignalTabread sTabread_N8FJrk2P;
  SignalRPole sRPole_Mwq1JUPV;
  SignalTabwrite sTabwrite_CRXpaWLf;
  SignalTabwrite sTabwrite_tbiNjGpj;
  SignalTabwrite sTabwrite_fMDwnoyS;
  SignalTabwrite sTabwrite_f2jBEpEb;
  SignalLine sLine_lRHeRMcZ;
  ControlVar cVar_UWMMT0e2;
  ControlVar cVar_CNGTiPGD;
  ControlPack cPack_o5HaKavT;
  ControlBinop cBinop_dto9N145;
  ControlVar cVar_041uOvaQ;
  ControlPack cPack_KyIvik6c;
  ControlVar cVar_PzCwzUWc;
  ControlVar cVar_qjD4She6;
  ControlDelay cDelay_PQrPsnNj;
  ControlDelay cDelay_kLCpSjFr;
  ControlBinop cBinop_BiXzhzMx;
  HvTable hTable_5RlnjNqp;
  ControlBinop cBinop_gpawZNsC;
  ControlVar cVar_QyLFhk7I;
  ControlBinop cBinop_lL6PuBRh;
  ControlBinop cBinop_z4VP5Fd7;
  SignalVarf sVarf_2ISjb7KL;
  SignalVarf sVarf_Bk2mIowD;
  SignalVarf sVarf_aUxx8GwO;
  ControlVar cVar_sxHvW3Pk;
  ControlBinop cBinop_iF6z6W7e;
  ControlBinop cBinop_sHyeSlZm;
  SignalVarf sVarf_CYBhd4ci;
  SignalVarf sVarf_UOT9j2j3;
  SignalVarf sVarf_68YGmFvT;
  ControlBinop cBinop_i1JxzCSN;
  ControlBinop cBinop_Zrs8R9NH;
  ControlBinop cBinop_9eYTy4tA;
  ControlBinop cBinop_NNseNfMN;
  ControlBinop cBinop_jHusmIMw;
  ControlBinop cBinop_ccVKv0bf;
  ControlBinop cBinop_p5uSI42P;
  ControlBinop cBinop_acbvDvP5;
  ControlBinop cBinop_E7aSCMRy;
  SignalVarf sVarf_rFwviVv3;
  ControlVar cVar_ZhRtlPuk;
  ControlBinop cBinop_Zw2g1GuU;
  ControlBinop cBinop_PMGQVlVS;
  ControlBinop cBinop_fwYbdoCH;
  ControlBinop cBinop_DI3L2GLF;
  ControlBinop cBinop_xND2xEe8;
  ControlBinop cBinop_T6xplnIO;
  ControlBinop cBinop_Lm58JNs8;
  SignalVarf sVarf_Ov7f08aZ;
  ControlBinop cBinop_98EhcLQC;
  ControlRandom cRandom_henzVE9I;
  ControlSlice cSlice_9cVvqcQb;
  ControlDelay cDelay_zXjXv8ut;
  ControlVar cVar_U9g3Nsw1;
  ControlBinop cBinop_M4TlyE7J;
  ControlBinop cBinop_GWsYAMm7;
  ControlBinop cBinop_HbnYuEk8;
  ControlTabhead cTabhead_EnArtQpq;
  ControlVar cVar_HkjIulP6;
  ControlDelay cDelay_LRQzYMw9;
  ControlDelay cDelay_uJMexdf4;
  ControlBinop cBinop_sSC8oqap;
  ControlBinop cBinop_qEYDC89C;
  ControlBinop cBinop_1FXRvxYU;
  ControlBinop cBinop_jE7aAKuB;
  ControlBinop cBinop_4fMBZ0Q9;
  ControlBinop cBinop_E7J2RT6B;
  ControlTabhead cTabhead_RGUU2kwj;
  ControlVar cVar_SHypic6p;
  ControlDelay cDelay_4XVpyPnP;
  ControlDelay cDelay_3UqkrnUY;
  ControlBinop cBinop_hGO85G7q;
  ControlBinop cBinop_ZTxEIaWh;
  ControlBinop cBinop_e47BMWTP;
  ControlBinop cBinop_5cz2krqD;
  ControlBinop cBinop_BOwfUEBH;
  ControlBinop cBinop_iL0njLex;
  ControlTabhead cTabhead_wx7xKHdW;
  ControlVar cVar_F5FHf6gp;
  ControlDelay cDelay_TzyFyHg2;
  ControlDelay cDelay_EQQXwJ0F;
  ControlBinop cBinop_jeW0Y2Li;
  ControlBinop cBinop_vjTrvljM;
  ControlBinop cBinop_4zg4JbE9;
  ControlBinop cBinop_A1NYb0cm;
  ControlBinop cBinop_DUuEXQJS;
  ControlBinop cBinop_GkeppHox;
  ControlTabhead cTabhead_7ca0893V;
  ControlVar cVar_60d20ORg;
  ControlDelay cDelay_FHWwSQnS;
  ControlDelay cDelay_SuESw1Mg;
  ControlBinop cBinop_6J9HYGEK;
  ControlBinop cBinop_xqvMPPeD;
  ControlBinop cBinop_em9JdRrU;
  ControlBinop cBinop_IeMFij0O;
  ControlBinop cBinop_6U3fNJ4z;
  ControlBinop cBinop_QTzzxmG8;
  ControlDelay cDelay_4ycZzfj4;
  ControlDelay cDelay_WgZYbQEF;
  ControlBinop cBinop_0b74NO31;
  HvTable hTable_wPdczNpJ;
  ControlBinop cBinop_OMcuQlUe;
  ControlDelay cDelay_rAaXvMc8;
  ControlDelay cDelay_1CzzuPvh;
  ControlBinop cBinop_DPBJTSJt;
  HvTable hTable_5A2r9Zyx;
  ControlBinop cBinop_gq1Ja6Sz;
  ControlDelay cDelay_502lqRWw;
  ControlDelay cDelay_MHYfMRRV;
  ControlBinop cBinop_KX35phux;
  HvTable hTable_TKbRAdvQ;
  ControlBinop cBinop_6AaX4dmd;
  ControlDelay cDelay_hN8EeENw;
  ControlDelay cDelay_jVxaXvU0;
  ControlBinop cBinop_hnReGYTG;
  HvTable hTable_7YuvHw7R;
  ControlBinop cBinop_TwYwm2eP;
  ControlPack cPack_K4PnQdXQ;
  ControlPack cPack_3YqwzeYQ;
  ControlBinop cBinop_zvL0pmQG;
  ControlBinop cBinop_Ev2ShP6O;
  ControlVar cVar_HSlGCHA7;
  ControlBinop cBinop_EMt4Vyzp;
  ControlBinop cBinop_qJBNjWFz;
  SignalVarf sVarf_dLE8noca;
  ControlBinop cBinop_vOzzieBv;
  ControlBinop cBinop_Z2fqK4pv;
  ControlBinop cBinop_b6qMY8ba;
  SignalVarf sVarf_wEWJpLdz;
  ControlVar cVar_F9qBmmsd;
  ControlVar cVar_AHOszjdX;
  ControlVar cVar_7r6dzwHN;
  ControlVar cVar_LKCycrEt;
  ControlIf cIf_poHZtvEi;
  ControlBinop cBinop_MHH8fvZm;
  ControlBinop cBinop_uOTpqZ4o;
  ControlBinop cBinop_k9Tqh78W;
  ControlDelay cDelay_0gXpYMnE;
  ControlDelay cDelay_gHlhYlC3;
  ControlBinop cBinop_wx6bMVdu;
  HvTable hTable_tNSn6Vtl;
  ControlBinop cBinop_ntGDMCz5;
  ControlTabhead cTabhead_aknAYwMb;
  ControlVar cVar_EefoUigE;
  ControlDelay cDelay_zxS67NUe;
  ControlDelay cDelay_bvprG8Eq;
  ControlBinop cBinop_HnCpE2GK;
  ControlBinop cBinop_FJ8u6v79;
  ControlBinop cBinop_cshdMLNj;
  ControlBinop cBinop_RBcDn6UE;
  ControlBinop cBinop_WJPMFlFB;
  ControlBinop cBinop_HKzwwybt;
  ControlDelay cDelay_7D0NBdb5;
  ControlDelay cDelay_9CqeH8rM;
  ControlBinop cBinop_7TucOsZh;
  HvTable hTable_MGugfUR6;
  ControlBinop cBinop_4s1WmBgp;
  ControlTabhead cTabhead_iXy9DCvI;
  ControlVar cVar_zlj8FHVf;
  ControlDelay cDelay_h6IeY1oP;
  ControlDelay cDelay_tY4ccei7;
  ControlBinop cBinop_AtQLUW4p;
  ControlBinop cBinop_Dvt3jHd4;
  ControlBinop cBinop_WNRhtGXf;
  ControlBinop cBinop_3s4DzZnl;
  ControlBinop cBinop_QHSaXxp8;
  ControlBinop cBinop_MmSlofXr;
  ControlDelay cDelay_VbLDURlZ;
  ControlDelay cDelay_wfw4TEHM;
  ControlBinop cBinop_Odz65GT9;
  HvTable hTable_emDYDVwz;
  ControlBinop cBinop_1bbqz5VD;
  ControlTabhead cTabhead_m6Etjp1n;
  ControlVar cVar_mqBwZ7gx;
  ControlDelay cDelay_3Ips83n2;
  ControlDelay cDelay_Cpfn0VK0;
  ControlBinop cBinop_V98jRqTH;
  ControlBinop cBinop_St1CHJh0;
  ControlBinop cBinop_9lyRiT9l;
  ControlBinop cBinop_2Q1TFB9U;
  ControlBinop cBinop_wgzYdmkm;
  ControlBinop cBinop_uG25ajUj;
  ControlDelay cDelay_eM3xHo9F;
  ControlDelay cDelay_4uJeTEIz;
  ControlBinop cBinop_cqMmf0bl;
  HvTable hTable_5tQbL0kn;
  ControlBinop cBinop_xUhMG1Lr;
  ControlTabhead cTabhead_hL9s3z62;
  ControlVar cVar_iegFFako;
  ControlDelay cDelay_U7gXAZEo;
  ControlDelay cDelay_na2rL4o7;
  ControlBinop cBinop_J6KpcyON;
  ControlBinop cBinop_vRRImeS0;
  ControlBinop cBinop_ku0MLZy6;
  ControlBinop cBinop_TMC0sOHC;
  ControlBinop cBinop_55ZChlxL;
  ControlBinop cBinop_XEFBhMPx;
  ControlDelay cDelay_RdQEwcJI;
  ControlDelay cDelay_Wr1XIBPV;
  ControlBinop cBinop_K1v0ye0Q;
  HvTable hTable_Avz2hLQx;
  ControlBinop cBinop_F6eU2Kuk;
  ControlTabhead cTabhead_Z8WE4sfU;
  ControlVar cVar_bRO7vB3t;
  ControlDelay cDelay_HT85cYWe;
  ControlDelay cDelay_oeZCRwUD;
  ControlBinop cBinop_lchHwaKp;
  ControlBinop cBinop_aqX9O9Bk;
  ControlBinop cBinop_ET00avC6;
  ControlBinop cBinop_ZHossFJC;
  ControlBinop cBinop_dQFdoT6s;
  ControlBinop cBinop_QJwEZ21f;
  ControlDelay cDelay_5EeaIJNV;
  ControlDelay cDelay_AKCvJFlb;
  ControlBinop cBinop_oFj8SUsR;
  HvTable hTable_ToCIyopm;
  ControlBinop cBinop_u6ETI3su;
  ControlTabhead cTabhead_6nDh6N0v;
  ControlVar cVar_83kHpFj9;
  ControlDelay cDelay_DkySWy7V;
  ControlDelay cDelay_3w7hwfiZ;
  ControlBinop cBinop_8Lk5ozKv;
  ControlBinop cBinop_9GUWdxxD;
  ControlBinop cBinop_FxaFlwTB;
  ControlBinop cBinop_z285CSYM;
  ControlBinop cBinop_GpKJyUM1;
  ControlBinop cBinop_RyMypoWH;
  ControlVar cVar_POKssBKH;
  ControlVar cVar_eeqrJpuU;
  ControlPack cPack_GlVwqoqn;
  ControlVar cVar_GbTlsh7E;
  ControlBinop cBinop_yYxWUfBD;
  ControlBinop cBinop_JmNGUXqG;
  SignalVarf sVarf_9hfZddUY;
  ControlBinop cBinop_s5BMpUzK;
  ControlBinop cBinop_DcVswJyU;
  ControlBinop cBinop_20NlDdF9;
  SignalVarf sVarf_MttIgxIx;
  ControlVar cVar_fVuXzs52;
  ControlBinop cBinop_8TIHPuUU;
  ControlBinop cBinop_nQzUBpC6;
  SignalVarf sVarf_0zS2SgK0;
  ControlBinop cBinop_qiarUK0k;
  ControlBinop cBinop_XtsuzYDn;
  ControlBinop cBinop_pqKoES14;
  SignalVarf sVarf_juFiOZ8o;
  ControlVar cVar_UHz1HLls;
  ControlBinop cBinop_5nCwwhn8;
  ControlBinop cBinop_RiYX2VrP;
  SignalVarf sVarf_KRCeIT5E;
  ControlBinop cBinop_Sq5sfbGx;
  ControlBinop cBinop_dIFSLBHA;
  ControlBinop cBinop_upHUBXAf;
  SignalVarf sVarf_g0jqgPS0;
  ControlBinop cBinop_m1KgPrbv;
  ControlBinop cBinop_xFFN2IkJ;
  ControlBinop cBinop_sc6FT59X;
  ControlDelay cDelay_QyU9T2L3;
  ControlVar cVar_5FSPIk4T;
  ControlBinop cBinop_wNHUks45;
  ControlBinop cBinop_qSJCm20t;
  ControlBinop cBinop_IduixJ1G;
  ControlVar cVar_WHXQ45N1;
  ControlVar cVar_DG3Qnaw3;
  ControlIf cIf_yBSky8vu;
  ControlBinop cBinop_jkcx0EbM;
  ControlDelay cDelay_MtFC3sg4;
  ControlDelay cDelay_Ib7httWY;
  ControlBinop cBinop_7J3uBwSI;
  HvTable hTable_1XjpSzeq;
  ControlBinop cBinop_mKvqHyNq;
  ControlTabhead cTabhead_sX1yC4Yi;
  ControlVar cVar_Mf8ghVRW;
  ControlDelay cDelay_wokSF4Wl;
  ControlDelay cDelay_PZkDYgok;
  ControlBinop cBinop_uzE64LDk;
  ControlBinop cBinop_tGt9XMi8;
  ControlBinop cBinop_fAeIc8ls;
  ControlBinop cBinop_SLTP6G7n;
  ControlBinop cBinop_Gsy6J4bQ;
  ControlBinop cBinop_GMatwuuu;
  ControlVar cVar_XT5xndzG;
  ControlVar cVar_bvxNzdgx;
  ControlVar cVar_TE6yMAFI;
  ControlVar cVar_UmJpRQmH;
  ControlVar cVar_fLJ1G8Dn;
  ControlVar cVar_qeIAI8zw;
  ControlIf cIf_n5bkwcMp;
  ControlBinop cBinop_FnKuJIBK;
  ControlVar cVar_VYz93BPg;
  ControlIf cIf_A2RTTro3;
  ControlBinop cBinop_4VxPk6DZ;
  ControlSlice cSlice_XBoxBlK0;
  ControlSlice cSlice_PfMGu1wg;
  ControlVar cVar_7QnUSpqE;
  ControlIf cIf_X40IJkea;
  ControlBinop cBinop_zG3kG6ph;
  ControlIf cIf_fJYHQjYf;
  ControlIf cIf_9wriYu8V;
  ControlIf cIf_vkCQZ1rg;
  ControlIf cIf_hX6bEGqo;
  ControlIf cIf_1jxL0xft;
  SignalVarf sVarf_AJhsVcAI;
  ControlBinop cBinop_B0Xmw2qN;
  ControlBinop cBinop_tH07Ncba;
  ControlBinop cBinop_YObEr6Bo;
  ControlBinop cBinop_YyON3lLQ;
  SignalVarf sVarf_C26mOGyy;
  ControlBinop cBinop_htC4fmL2;
  ControlBinop cBinop_hdGo7jCx;
  SignalVarf sVarf_Z5SnoerC;
  SignalVarf sVarf_9aSE8m2S;
  ControlBinop cBinop_CPBSaMbL;
  ControlBinop cBinop_8pmQVdbu;
  ControlBinop cBinop_KkFLowWC;
  ControlBinop cBinop_TOxUo8qB;
  ControlBinop cBinop_SNgSt2KJ;
  ControlBinop cBinop_hVA6EyMb;
  ControlBinop cBinop_4pFQ3Cfh;
  ControlBinop cBinop_GuTABrHs;
  ControlBinop cBinop_jaxSsEro;
  ControlBinop cBinop_3AVeJRA9;
  ControlBinop cBinop_VltMNnFU;
  ControlBinop cBinop_Dh9ifyfo;
  ControlBinop cBinop_jjCntwxR;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
