/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_dzgHu6BW, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_hUAIaXYQ);
  numBytes += sLine_init(&sLine_rvsqBg5L);
  numBytes += sTabhead_init(&sTabhead_palhez3K, &hTable_5RlnjNqp);
  numBytes += sTabread_init(&sTabread_1vUeBqrD, &hTable_5RlnjNqp, false);
  numBytes += sTabread_init(&sTabread_xXLWRIvO, &hTable_5RlnjNqp, false);
  numBytes += sTabhead_init(&sTabhead_bmEa0HnT, &hTable_5RlnjNqp);
  numBytes += sTabread_init(&sTabread_cYpoUHYw, &hTable_5RlnjNqp, false);
  numBytes += sTabread_init(&sTabread_fcyAYF4R, &hTable_5RlnjNqp, false);
  numBytes += sTabwrite_init(&sTabwrite_WTuF4Gkk, &hTable_5RlnjNqp);
  numBytes += sRPole_init(&sRPole_wYz5cVrI);
  numBytes += sDel1_init(&sDel1_EdfxeXAJ);
  numBytes += sTabread_init(&sTabread_Lx5Bs3di, &hTable_1XjpSzeq, true);
  numBytes += sTabwrite_init(&sTabwrite_1vQ6VjNe, &hTable_1XjpSzeq);
  numBytes += sTabread_init(&sTabread_PDe0HwNj, &hTable_wPdczNpJ, true);
  numBytes += sRPole_init(&sRPole_pfJJGFwL);
  numBytes += sLine_init(&sLine_1a7Hv02L);
  numBytes += sLine_init(&sLine_Ezfv51Su);
  numBytes += sTabread_init(&sTabread_md9W2lHD, &hTable_tNSn6Vtl, true);
  numBytes += sTabread_init(&sTabread_frKbON3F, &hTable_MGugfUR6, true);
  numBytes += sTabread_init(&sTabread_EogYwzgO, &hTable_emDYDVwz, true);
  numBytes += sTabread_init(&sTabread_1ApzqGAn, &hTable_5tQbL0kn, true);
  numBytes += sTabread_init(&sTabread_mYYZ7gvP, &hTable_ToCIyopm, true);
  numBytes += sTabread_init(&sTabread_rY7yVUSK, &hTable_Avz2hLQx, true);
  numBytes += sTabwrite_init(&sTabwrite_IaUKLhF8, &hTable_tNSn6Vtl);
  numBytes += sTabwrite_init(&sTabwrite_uJNO9xsm, &hTable_MGugfUR6);
  numBytes += sTabwrite_init(&sTabwrite_fOjMITgU, &hTable_emDYDVwz);
  numBytes += sTabwrite_init(&sTabwrite_WuoAJjGa, &hTable_5tQbL0kn);
  numBytes += sTabwrite_init(&sTabwrite_2yXCFzXM, &hTable_Avz2hLQx);
  numBytes += sTabwrite_init(&sTabwrite_E5r8nFey, &hTable_ToCIyopm);
  numBytes += sTabread_init(&sTabread_IzrpiWte, &hTable_5A2r9Zyx, true);
  numBytes += sRPole_init(&sRPole_hvV9Sj9O);
  numBytes += sTabread_init(&sTabread_qc2b87oB, &hTable_TKbRAdvQ, true);
  numBytes += sRPole_init(&sRPole_sjpdBdLw);
  numBytes += sTabread_init(&sTabread_N8FJrk2P, &hTable_7YuvHw7R, true);
  numBytes += sRPole_init(&sRPole_Mwq1JUPV);
  numBytes += sTabwrite_init(&sTabwrite_CRXpaWLf, &hTable_wPdczNpJ);
  numBytes += sTabwrite_init(&sTabwrite_tbiNjGpj, &hTable_5A2r9Zyx);
  numBytes += sTabwrite_init(&sTabwrite_fMDwnoyS, &hTable_TKbRAdvQ);
  numBytes += sTabwrite_init(&sTabwrite_f2jBEpEb, &hTable_7YuvHw7R);
  numBytes += sLine_init(&sLine_lRHeRMcZ);
  numBytes += cVar_init_f(&cVar_UWMMT0e2, 0.0f);
  numBytes += cVar_init_f(&cVar_CNGTiPGD, 0.0f);
  numBytes += cPack_init(&cPack_o5HaKavT, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_041uOvaQ, 0.0f);
  numBytes += cPack_init(&cPack_KyIvik6c, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_PzCwzUWc, 0.0f);
  numBytes += cVar_init_f(&cVar_qjD4She6, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PQrPsnNj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kLCpSjFr, 0.0f);
  numBytes += hTable_init(&hTable_5RlnjNqp, 256);
  numBytes += cVar_init_s(&cVar_QyLFhk7I, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_2ISjb7KL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bk2mIowD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aUxx8GwO, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_sxHvW3Pk, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_CYBhd4ci, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UOT9j2j3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_68YGmFvT, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_i1JxzCSN, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_rFwviVv3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZhRtlPuk, 0.0f);
  numBytes += cBinop_init(&cBinop_Lm58JNs8, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Ov7f08aZ, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_henzVE9I, -769897922);
  numBytes += cSlice_init(&cSlice_9cVvqcQb, 1, 1);
  numBytes += cDelay_init(this, &cDelay_zXjXv8ut, 0.0f);
  numBytes += cVar_init_f(&cVar_U9g3Nsw1, 5.0f);
  numBytes += cBinop_init(&cBinop_HbnYuEk8, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_EnArtQpq, &hTable_wPdczNpJ);
  numBytes += cVar_init_s(&cVar_HkjIulP6, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_LRQzYMw9, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_uJMexdf4, 0.0f);
  numBytes += cBinop_init(&cBinop_sSC8oqap, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_1FXRvxYU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_jE7aAKuB, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_E7J2RT6B, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_RGUU2kwj, &hTable_5A2r9Zyx);
  numBytes += cVar_init_s(&cVar_SHypic6p, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_4XVpyPnP, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_3UqkrnUY, 0.0f);
  numBytes += cBinop_init(&cBinop_hGO85G7q, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_e47BMWTP, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_5cz2krqD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_iL0njLex, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_wx7xKHdW, &hTable_TKbRAdvQ);
  numBytes += cVar_init_s(&cVar_F5FHf6gp, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_TzyFyHg2, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_EQQXwJ0F, 0.0f);
  numBytes += cBinop_init(&cBinop_jeW0Y2Li, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_4zg4JbE9, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_A1NYb0cm, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GkeppHox, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_7ca0893V, &hTable_7YuvHw7R);
  numBytes += cVar_init_s(&cVar_60d20ORg, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_FHWwSQnS, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_SuESw1Mg, 0.0f);
  numBytes += cBinop_init(&cBinop_6J9HYGEK, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_em9JdRrU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_IeMFij0O, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_QTzzxmG8, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_4ycZzfj4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WgZYbQEF, 0.0f);
  numBytes += hTable_init(&hTable_wPdczNpJ, 256);
  numBytes += cDelay_init(this, &cDelay_rAaXvMc8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_1CzzuPvh, 0.0f);
  numBytes += hTable_init(&hTable_5A2r9Zyx, 256);
  numBytes += cDelay_init(this, &cDelay_502lqRWw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_MHYfMRRV, 0.0f);
  numBytes += hTable_init(&hTable_TKbRAdvQ, 256);
  numBytes += cDelay_init(this, &cDelay_hN8EeENw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_jVxaXvU0, 0.0f);
  numBytes += hTable_init(&hTable_7YuvHw7R, 256);
  numBytes += cPack_init(&cPack_K4PnQdXQ, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_3YqwzeYQ, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_HSlGCHA7, 22050.0f);
  numBytes += cBinop_init(&cBinop_EMt4Vyzp, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_dLE8noca, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wEWJpLdz, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_F9qBmmsd, 0.0f);
  numBytes += cVar_init_f(&cVar_AHOszjdX, 0.0f);
  numBytes += cVar_init_f(&cVar_7r6dzwHN, 0.0f);
  numBytes += cVar_init_f(&cVar_LKCycrEt, 0.0f);
  numBytes += cIf_init(&cIf_poHZtvEi, false);
  numBytes += cDelay_init(this, &cDelay_0gXpYMnE, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gHlhYlC3, 0.0f);
  numBytes += hTable_init(&hTable_tNSn6Vtl, 256);
  numBytes += cTabhead_init(&cTabhead_aknAYwMb, &hTable_tNSn6Vtl);
  numBytes += cVar_init_s(&cVar_EefoUigE, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_zxS67NUe, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_bvprG8Eq, 0.0f);
  numBytes += cBinop_init(&cBinop_HnCpE2GK, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_cshdMLNj, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_RBcDn6UE, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_HKzwwybt, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_7D0NBdb5, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9CqeH8rM, 0.0f);
  numBytes += hTable_init(&hTable_MGugfUR6, 256);
  numBytes += cTabhead_init(&cTabhead_iXy9DCvI, &hTable_MGugfUR6);
  numBytes += cVar_init_s(&cVar_zlj8FHVf, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_h6IeY1oP, 25.796f);
  numBytes += cDelay_init(this, &cDelay_tY4ccei7, 0.0f);
  numBytes += cBinop_init(&cBinop_AtQLUW4p, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_WNRhtGXf, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_3s4DzZnl, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_MmSlofXr, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_VbLDURlZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wfw4TEHM, 0.0f);
  numBytes += hTable_init(&hTable_emDYDVwz, 256);
  numBytes += cTabhead_init(&cTabhead_m6Etjp1n, &hTable_emDYDVwz);
  numBytes += cVar_init_s(&cVar_mqBwZ7gx, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_3Ips83n2, 19.392f);
  numBytes += cDelay_init(this, &cDelay_Cpfn0VK0, 0.0f);
  numBytes += cBinop_init(&cBinop_V98jRqTH, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_9lyRiT9l, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_2Q1TFB9U, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_uG25ajUj, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_eM3xHo9F, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4uJeTEIz, 0.0f);
  numBytes += hTable_init(&hTable_5tQbL0kn, 256);
  numBytes += cTabhead_init(&cTabhead_hL9s3z62, &hTable_5tQbL0kn);
  numBytes += cVar_init_s(&cVar_iegFFako, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_U7gXAZEo, 16.364f);
  numBytes += cDelay_init(this, &cDelay_na2rL4o7, 0.0f);
  numBytes += cBinop_init(&cBinop_J6KpcyON, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_ku0MLZy6, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_TMC0sOHC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_XEFBhMPx, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_RdQEwcJI, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Wr1XIBPV, 0.0f);
  numBytes += hTable_init(&hTable_Avz2hLQx, 256);
  numBytes += cTabhead_init(&cTabhead_Z8WE4sfU, &hTable_Avz2hLQx);
  numBytes += cVar_init_s(&cVar_bRO7vB3t, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_HT85cYWe, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_oeZCRwUD, 0.0f);
  numBytes += cBinop_init(&cBinop_lchHwaKp, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_ET00avC6, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ZHossFJC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_QJwEZ21f, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_5EeaIJNV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_AKCvJFlb, 0.0f);
  numBytes += hTable_init(&hTable_ToCIyopm, 256);
  numBytes += cTabhead_init(&cTabhead_6nDh6N0v, &hTable_ToCIyopm);
  numBytes += cVar_init_s(&cVar_83kHpFj9, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_DkySWy7V, 7.645f);
  numBytes += cDelay_init(this, &cDelay_3w7hwfiZ, 0.0f);
  numBytes += cBinop_init(&cBinop_8Lk5ozKv, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_FxaFlwTB, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_z285CSYM, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_RyMypoWH, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_POKssBKH, 0.0f);
  numBytes += cVar_init_f(&cVar_eeqrJpuU, 0.0f);
  numBytes += cPack_init(&cPack_GlVwqoqn, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_GbTlsh7E, 22050.0f);
  numBytes += cBinop_init(&cBinop_yYxWUfBD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9hfZddUY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MttIgxIx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fVuXzs52, 22050.0f);
  numBytes += cBinop_init(&cBinop_8TIHPuUU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0zS2SgK0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_juFiOZ8o, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_UHz1HLls, 22050.0f);
  numBytes += cBinop_init(&cBinop_5nCwwhn8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_KRCeIT5E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g0jqgPS0, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_QyU9T2L3, 0.0f);
  numBytes += cVar_init_f(&cVar_5FSPIk4T, 1000.0f);
  numBytes += cBinop_init(&cBinop_IduixJ1G, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WHXQ45N1, 0.0f);
  numBytes += cVar_init_f(&cVar_DG3Qnaw3, 0.0f);
  numBytes += cIf_init(&cIf_yBSky8vu, false);
  numBytes += cDelay_init(this, &cDelay_MtFC3sg4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Ib7httWY, 0.0f);
  numBytes += hTable_init(&hTable_1XjpSzeq, 256);
  numBytes += cTabhead_init(&cTabhead_sX1yC4Yi, &hTable_1XjpSzeq);
  numBytes += cVar_init_s(&cVar_Mf8ghVRW, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_wokSF4Wl, 150.0f);
  numBytes += cDelay_init(this, &cDelay_PZkDYgok, 0.0f);
  numBytes += cBinop_init(&cBinop_uzE64LDk, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_fAeIc8ls, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_SLTP6G7n, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GMatwuuu, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_XT5xndzG, 0.0f);
  numBytes += cVar_init_f(&cVar_bvxNzdgx, 0.0f);
  numBytes += cVar_init_f(&cVar_TE6yMAFI, 0.0f);
  numBytes += cVar_init_f(&cVar_UmJpRQmH, 0.0f);
  numBytes += cVar_init_f(&cVar_fLJ1G8Dn, 0.0f);
  numBytes += cVar_init_f(&cVar_qeIAI8zw, 0.0f);
  numBytes += cIf_init(&cIf_n5bkwcMp, false);
  numBytes += cVar_init_f(&cVar_VYz93BPg, 0.0f);
  numBytes += cIf_init(&cIf_A2RTTro3, false);
  numBytes += cSlice_init(&cSlice_XBoxBlK0, 1, -1);
  numBytes += cSlice_init(&cSlice_PfMGu1wg, 1, -1);
  numBytes += cVar_init_f(&cVar_7QnUSpqE, 0.0f);
  numBytes += cIf_init(&cIf_X40IJkea, false);
  numBytes += cBinop_init(&cBinop_zG3kG6ph, 0.0f); // __neq
  numBytes += cIf_init(&cIf_fJYHQjYf, false);
  numBytes += cIf_init(&cIf_9wriYu8V, false);
  numBytes += cIf_init(&cIf_vkCQZ1rg, false);
  numBytes += cIf_init(&cIf_hX6bEGqo, true);
  numBytes += cIf_init(&cIf_1jxL0xft, false);
  numBytes += sVarf_init(&sVarf_AJhsVcAI, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_YObEr6Bo, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_C26mOGyy, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_htC4fmL2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_hdGo7jCx, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_Z5SnoerC, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9aSE8m2S, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_8pmQVdbu, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_jaxSsEro, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_3AVeJRA9, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_VltMNnFU, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Dh9ifyfo, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_jjCntwxR, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_o5HaKavT);
  cPack_free(&cPack_KyIvik6c);
  hTable_free(&hTable_5RlnjNqp);
  hTable_free(&hTable_wPdczNpJ);
  hTable_free(&hTable_5A2r9Zyx);
  hTable_free(&hTable_TKbRAdvQ);
  hTable_free(&hTable_7YuvHw7R);
  cPack_free(&cPack_K4PnQdXQ);
  cPack_free(&cPack_3YqwzeYQ);
  hTable_free(&hTable_tNSn6Vtl);
  hTable_free(&hTable_MGugfUR6);
  hTable_free(&hTable_emDYDVwz);
  hTable_free(&hTable_5tQbL0kn);
  hTable_free(&hTable_Avz2hLQx);
  hTable_free(&hTable_ToCIyopm);
  cPack_free(&cPack_GlVwqoqn);
  hTable_free(&hTable_1XjpSzeq);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_5RlnjNqp; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_wPdczNpJ; // del-1052-del1
    case 0xA2AC524D: return &hTable_5A2r9Zyx; // del-1052-del2
    case 0xE36A35B: return &hTable_TKbRAdvQ; // del-1052-del3
    case 0x48CE0509: return &hTable_7YuvHw7R; // del-1052-del4
    case 0xE34D6E72: return &hTable_tNSn6Vtl; // del-1052-ref1
    case 0x6A1027AB: return &hTable_MGugfUR6; // del-1052-ref2
    case 0xA37C6D49: return &hTable_emDYDVwz; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_5tQbL0kn; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_Avz2hLQx; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_ToCIyopm; // del-1052-ref5
    case 0xED65564F: return &hTable_1XjpSzeq; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T6Jr708P_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AFW90A92_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EllY8nDL_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9xfmKe1C_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vmRG0h4W_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_91lhiHbO_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qXdky84I_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ECxQXQ5V_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6XGFo1Kh_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J0hSlsEz_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yUxrBDcQ_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WRiik0Nw_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1LVkPoXn_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aYN5EBXv_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QnS0u8yf_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sG45Gr5u_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2KegU7qJ_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0E3gQzdW_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_edWEiymq_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uYvPOAq2_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gp8Ta2RC_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bux2lCNZ_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5ZpXWD4o_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ro4ekVBg_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_UWMMT0e2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_NNseNfMN_sendMessage);
}

void Heavy_ChaffVerb::cVar_CNGTiPGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_p5uSI42P_sendMessage);
}

void Heavy_ChaffVerb::cPack_o5HaKavT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_hUAIaXYQ, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_xMNgVWee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_041uOvaQ, 0, m, &cVar_041uOvaQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dto9N145_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_xMNgVWee_sendMessage);
}

void Heavy_ChaffVerb::cVar_041uOvaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9eYTy4tA_sendMessage);
}

void Heavy_ChaffVerb::cPack_KyIvik6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_rvsqBg5L, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_PzCwzUWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_ccVKv0bf_sendMessage);
}

void Heavy_ChaffVerb::cVar_qjD4She6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_dzgHu6BW, 0, m);
}

void Heavy_ChaffVerb::cMsg_oZSr7Hb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qsHKyMEN_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qsHKyMEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gpawZNsC_sendMessage);
}

void Heavy_ChaffVerb::cDelay_PQrPsnNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PQrPsnNj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kLCpSjFr, 0, m, &cDelay_kLCpSjFr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQrPsnNj, 0, m, &cDelay_PQrPsnNj_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WTuF4Gkk, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_kLCpSjFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kLCpSjFr, m);
  cMsg_EUY0HAAt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_zMsmAeVP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_xY9XhAdL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_BiXzhzMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rM8RXP58_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_5RlnjNqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ddimt9OH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQrPsnNj, 2, m, &cDelay_PQrPsnNj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eXmPuBGu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rM8RXP58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5RlnjNqp, 0, m, &hTable_5RlnjNqp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gpawZNsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_BiXzhzMx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EUY0HAAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5RlnjNqp, 0, m, &hTable_5RlnjNqp_sendMessage);
}

void Heavy_ChaffVerb::cCast_eXmPuBGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PQrPsnNj, 0, m, &cDelay_PQrPsnNj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ddimt9OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kLCpSjFr, 2, m, &cDelay_kLCpSjFr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xY9XhAdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WTuF4Gkk, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_jNN6ubuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4lNLt9oP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4lNLt9oP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lL6PuBRh_sendMessage);
}

void Heavy_ChaffVerb::cVar_QyLFhk7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T9EVgGTq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_oRPSlwp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_z4VP5Fd7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2ISjb7KL, m);
}

void Heavy_ChaffVerb::cBinop_lL6PuBRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bk2mIowD, m);
}

void Heavy_ChaffVerb::cMsg_T9EVgGTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oRPSlwp3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z4VP5Fd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_aUxx8GwO, m);
}

void Heavy_ChaffVerb::cMsg_qSD6jZ09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_04EA2d7W_sendMessage);
}

void Heavy_ChaffVerb::cSystem_04EA2d7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iF6z6W7e_sendMessage);
}

void Heavy_ChaffVerb::cVar_sxHvW3Pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aRfU7Jx1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_d3oQswTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_sHyeSlZm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CYBhd4ci, m);
}

void Heavy_ChaffVerb::cBinop_iF6z6W7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UOT9j2j3, m);
}

void Heavy_ChaffVerb::cMsg_aRfU7Jx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_d3oQswTv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sHyeSlZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_68YGmFvT, m);
}

void Heavy_ChaffVerb::cBinop_i1JxzCSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qjD4She6, 0, m, &cVar_qjD4She6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zrs8R9NH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I98ZqBUh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MH22F9SL_sendMessage);
}

void Heavy_ChaffVerb::cCast_MH22F9SL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i1JxzCSN, HV_BINOP_DIVIDE, 0, m, &cBinop_i1JxzCSN_sendMessage);
}

void Heavy_ChaffVerb::cCast_I98ZqBUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i1JxzCSN, HV_BINOP_DIVIDE, 1, m, &cBinop_i1JxzCSN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9eYTy4tA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jHusmIMw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NNseNfMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_dto9N145_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jHusmIMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i1JxzCSN, HV_BINOP_DIVIDE, 0, m, &cBinop_i1JxzCSN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ccVKv0bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_KyIvik6c, 0, m, &cPack_KyIvik6c_sendMessage);
}

void Heavy_ChaffVerb::cBinop_p5uSI42P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_Zrs8R9NH_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_o5HaKavT, 0, m, &cPack_o5HaKavT_sendMessage);
}

void Heavy_ChaffVerb::cUnop_DO3V3mTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9wriYu8V, 0, m, &cIf_9wriYu8V_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_b6vx3HyZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iyp7cWZX_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VPdtjXQ3_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JmSqiTAO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_Iyp7cWZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dNewLAvF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_VPdtjXQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0EYrv1rN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_JmSqiTAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nWjUTx6P_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_acbvDvP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_E7aSCMRy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E7aSCMRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Zw2g1GuU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DI3L2GLF_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZhRtlPuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_xND2xEe8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7A6SB9av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_faOmb4Xe_sendMessage);
}

void Heavy_ChaffVerb::cSystem_faOmb4Xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lm58JNs8, HV_BINOP_DIVIDE, 1, m, &cBinop_Lm58JNs8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zw2g1GuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PMGQVlVS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PMGQVlVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ov7f08aZ, m);
}

void Heavy_ChaffVerb::cMsg_OFIYybSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fwYbdoCH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fwYbdoCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_acbvDvP5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DI3L2GLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rFwviVv3, m);
}

void Heavy_ChaffVerb::cBinop_xND2xEe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_T6xplnIO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T6xplnIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lm58JNs8, HV_BINOP_DIVIDE, 0, m, &cBinop_Lm58JNs8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Lm58JNs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OFIYybSY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_4mvOr2Ug_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9cVvqcQb, 0, m, &cSlice_9cVvqcQb_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_henzVE9I, 0, m, &cRandom_henzVE9I_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_98EhcLQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_0GITFccM_sendMessage);
}

void Heavy_ChaffVerb::cUnop_0GITFccM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_tH07Ncba_sendMessage);
}

void Heavy_ChaffVerb::cRandom_henzVE9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_98EhcLQC_sendMessage);
}

void Heavy_ChaffVerb::cSlice_9cVvqcQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_henzVE9I, 1, m, &cRandom_henzVE9I_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_SeI6HxYr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_Xy8PGSrs_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_Xy8PGSrs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0imByWwF_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_zXjXv8ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zXjXv8ut, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zXjXv8ut, 0, m, &cDelay_zXjXv8ut_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WHXQ45N1, 0, m, &cVar_WHXQ45N1_sendMessage);
}

void Heavy_ChaffVerb::cCast_0imByWwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xy8PGSrs_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zXjXv8ut, 0, m, &cDelay_zXjXv8ut_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WHXQ45N1, 0, m, &cVar_WHXQ45N1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yiOritOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WjMk9LLV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_WjMk9LLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GWsYAMm7_sendMessage);
}

void Heavy_ChaffVerb::cVar_U9g3Nsw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HbnYuEk8, HV_BINOP_MULTIPLY, 0, m, &cBinop_HbnYuEk8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Xy8PGSrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zXjXv8ut, 0, m, &cDelay_zXjXv8ut_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M4TlyE7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zXjXv8ut, 2, m, &cDelay_zXjXv8ut_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GWsYAMm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HbnYuEk8, HV_BINOP_MULTIPLY, 1, m, &cBinop_HbnYuEk8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HbnYuEk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_M4TlyE7J_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_EnArtQpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1FXRvxYU, HV_BINOP_SUBTRACT, 0, m, &cBinop_1FXRvxYU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pVy2P2Uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_deCWU9ZM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_deCWU9ZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qEYDC89C_sendMessage);
}

void Heavy_ChaffVerb::cVar_HkjIulP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7rjx08BG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_LRQzYMw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LRQzYMw9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uJMexdf4, 0, m, &cDelay_uJMexdf4_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PDe0HwNj, 0, m, &sTabread_PDe0HwNj_sendMessage);
}

void Heavy_ChaffVerb::cDelay_uJMexdf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uJMexdf4, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PDe0HwNj, 0, m, &sTabread_PDe0HwNj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uJMexdf4, 0, m, &cDelay_uJMexdf4_sendMessage);
}

void Heavy_ChaffVerb::sTabread_PDe0HwNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_E7J2RT6B, HV_BINOP_SUBTRACT, 0, m, &cBinop_E7J2RT6B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_sSC8oqap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jE7aAKuB, HV_BINOP_MAX, 0, m, &cBinop_jE7aAKuB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qEYDC89C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSC8oqap, HV_BINOP_MULTIPLY, 0, m, &cBinop_sSC8oqap_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1FXRvxYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jGVxBwDo_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PDe0HwNj, 0, m, &sTabread_PDe0HwNj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0B3Nopad_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6oybqGk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E7J2RT6B, HV_BINOP_SUBTRACT, 1, m, &cBinop_E7J2RT6B_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uJMexdf4, 2, m, &cDelay_uJMexdf4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7rjx08BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6oybqGk1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jGVxBwDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LRQzYMw9, 0, m, &cDelay_LRQzYMw9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uJMexdf4, 0, m, &cDelay_uJMexdf4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NlcBv8Ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_jE7aAKuB, HV_BINOP_MAX, 1, m, &cBinop_jE7aAKuB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jE7aAKuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1FXRvxYU, HV_BINOP_SUBTRACT, 1, m, &cBinop_1FXRvxYU_sendMessage);
}

void Heavy_ChaffVerb::cCast_0B3Nopad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LRQzYMw9, 0, m, &cDelay_LRQzYMw9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4fMBZ0Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LRQzYMw9, 2, m, &cDelay_LRQzYMw9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E7J2RT6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4fMBZ0Q9_sendMessage);
}

void Heavy_ChaffVerb::cCast_I7UnMYKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HkjIulP6, 0, m, &cVar_HkjIulP6_sendMessage);
  cMsg_pVy2P2Uf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_EnArtQpq, 0, m, &cTabhead_EnArtQpq_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_RGUU2kwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e47BMWTP, HV_BINOP_SUBTRACT, 0, m, &cBinop_e47BMWTP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_86xi66Xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_M7ji9KlC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_M7ji9KlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZTxEIaWh_sendMessage);
}

void Heavy_ChaffVerb::cVar_SHypic6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u4wuJboI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_4XVpyPnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4XVpyPnP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3UqkrnUY, 0, m, &cDelay_3UqkrnUY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_IzrpiWte, 0, m, &sTabread_IzrpiWte_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3UqkrnUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3UqkrnUY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_IzrpiWte, 0, m, &sTabread_IzrpiWte_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3UqkrnUY, 0, m, &cDelay_3UqkrnUY_sendMessage);
}

void Heavy_ChaffVerb::sTabread_IzrpiWte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iL0njLex, HV_BINOP_SUBTRACT, 0, m, &cBinop_iL0njLex_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_hGO85G7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5cz2krqD, HV_BINOP_MAX, 0, m, &cBinop_5cz2krqD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZTxEIaWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hGO85G7q, HV_BINOP_MULTIPLY, 0, m, &cBinop_hGO85G7q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_e47BMWTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U5jdyOZv_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_IzrpiWte, 0, m, &sTabread_IzrpiWte_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PtXT00lY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dKQMqXRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iL0njLex, HV_BINOP_SUBTRACT, 1, m, &cBinop_iL0njLex_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3UqkrnUY, 2, m, &cDelay_3UqkrnUY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_u4wuJboI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dKQMqXRg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_U5jdyOZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4XVpyPnP, 0, m, &cDelay_4XVpyPnP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3UqkrnUY, 0, m, &cDelay_3UqkrnUY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FPFmKDaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_5cz2krqD, HV_BINOP_MAX, 1, m, &cBinop_5cz2krqD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5cz2krqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e47BMWTP, HV_BINOP_SUBTRACT, 1, m, &cBinop_e47BMWTP_sendMessage);
}

void Heavy_ChaffVerb::cCast_PtXT00lY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4XVpyPnP, 0, m, &cDelay_4XVpyPnP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BOwfUEBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4XVpyPnP, 2, m, &cDelay_4XVpyPnP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iL0njLex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BOwfUEBH_sendMessage);
}

void Heavy_ChaffVerb::cCast_VLGA3Y6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SHypic6p, 0, m, &cVar_SHypic6p_sendMessage);
  cMsg_86xi66Xw_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RGUU2kwj, 0, m, &cTabhead_RGUU2kwj_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_wx7xKHdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4zg4JbE9, HV_BINOP_SUBTRACT, 0, m, &cBinop_4zg4JbE9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uvmjNcu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_45e3AZyT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_45e3AZyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vjTrvljM_sendMessage);
}

void Heavy_ChaffVerb::cVar_F5FHf6gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z8RD8CoU_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_TzyFyHg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TzyFyHg2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EQQXwJ0F, 0, m, &cDelay_EQQXwJ0F_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qc2b87oB, 0, m, &sTabread_qc2b87oB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_EQQXwJ0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EQQXwJ0F, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qc2b87oB, 0, m, &sTabread_qc2b87oB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EQQXwJ0F, 0, m, &cDelay_EQQXwJ0F_sendMessage);
}

void Heavy_ChaffVerb::sTabread_qc2b87oB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GkeppHox, HV_BINOP_SUBTRACT, 0, m, &cBinop_GkeppHox_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_jeW0Y2Li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A1NYb0cm, HV_BINOP_MAX, 0, m, &cBinop_A1NYb0cm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vjTrvljM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jeW0Y2Li, HV_BINOP_MULTIPLY, 0, m, &cBinop_jeW0Y2Li_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4zg4JbE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jCGEMSeI_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qc2b87oB, 0, m, &sTabread_qc2b87oB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TvqKpzmb_sendMessage);
}

void Heavy_ChaffVerb::cSystem_786hsxnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GkeppHox, HV_BINOP_SUBTRACT, 1, m, &cBinop_GkeppHox_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EQQXwJ0F, 2, m, &cDelay_EQQXwJ0F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_z8RD8CoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_786hsxnO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jCGEMSeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TzyFyHg2, 0, m, &cDelay_TzyFyHg2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EQQXwJ0F, 0, m, &cDelay_EQQXwJ0F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EcdDd8Bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_A1NYb0cm, HV_BINOP_MAX, 1, m, &cBinop_A1NYb0cm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_A1NYb0cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4zg4JbE9, HV_BINOP_SUBTRACT, 1, m, &cBinop_4zg4JbE9_sendMessage);
}

void Heavy_ChaffVerb::cCast_TvqKpzmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TzyFyHg2, 0, m, &cDelay_TzyFyHg2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DUuEXQJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TzyFyHg2, 2, m, &cDelay_TzyFyHg2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GkeppHox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DUuEXQJS_sendMessage);
}

void Heavy_ChaffVerb::cCast_12O3sDim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F5FHf6gp, 0, m, &cVar_F5FHf6gp_sendMessage);
  cMsg_uvmjNcu1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wx7xKHdW, 0, m, &cTabhead_wx7xKHdW_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_7ca0893V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_em9JdRrU, HV_BINOP_SUBTRACT, 0, m, &cBinop_em9JdRrU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rFfu09ED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PF0yMMN7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_PF0yMMN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xqvMPPeD_sendMessage);
}

void Heavy_ChaffVerb::cVar_60d20ORg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VQtqKiNL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_FHWwSQnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FHWwSQnS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SuESw1Mg, 0, m, &cDelay_SuESw1Mg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N8FJrk2P, 0, m, &sTabread_N8FJrk2P_sendMessage);
}

void Heavy_ChaffVerb::cDelay_SuESw1Mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SuESw1Mg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N8FJrk2P, 0, m, &sTabread_N8FJrk2P_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SuESw1Mg, 0, m, &cDelay_SuESw1Mg_sendMessage);
}

void Heavy_ChaffVerb::sTabread_N8FJrk2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_QTzzxmG8, HV_BINOP_SUBTRACT, 0, m, &cBinop_QTzzxmG8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_6J9HYGEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IeMFij0O, HV_BINOP_MAX, 0, m, &cBinop_IeMFij0O_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xqvMPPeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6J9HYGEK, HV_BINOP_MULTIPLY, 0, m, &cBinop_6J9HYGEK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_em9JdRrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VhNvCswW_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N8FJrk2P, 0, m, &sTabread_N8FJrk2P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JWWHzN7O_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SOnWiJDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QTzzxmG8, HV_BINOP_SUBTRACT, 1, m, &cBinop_QTzzxmG8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SuESw1Mg, 2, m, &cDelay_SuESw1Mg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VQtqKiNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SOnWiJDF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VhNvCswW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FHWwSQnS, 0, m, &cDelay_FHWwSQnS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SuESw1Mg, 0, m, &cDelay_SuESw1Mg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IjtQSA3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_IeMFij0O, HV_BINOP_MAX, 1, m, &cBinop_IeMFij0O_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IeMFij0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_em9JdRrU, HV_BINOP_SUBTRACT, 1, m, &cBinop_em9JdRrU_sendMessage);
}

void Heavy_ChaffVerb::cCast_JWWHzN7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FHWwSQnS, 0, m, &cDelay_FHWwSQnS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6U3fNJ4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FHWwSQnS, 2, m, &cDelay_FHWwSQnS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QTzzxmG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6U3fNJ4z_sendMessage);
}

void Heavy_ChaffVerb::cCast_0pncQUGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_60d20ORg, 0, m, &cVar_60d20ORg_sendMessage);
  cMsg_rFfu09ED_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7ca0893V, 0, m, &cTabhead_7ca0893V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yCZswnsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LoLPI6jy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_LoLPI6jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OMcuQlUe_sendMessage);
}

void Heavy_ChaffVerb::cDelay_4ycZzfj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4ycZzfj4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WgZYbQEF, 0, m, &cDelay_WgZYbQEF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ycZzfj4, 0, m, &cDelay_4ycZzfj4_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CRXpaWLf, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_WgZYbQEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WgZYbQEF, m);
  cMsg_kF0mRabj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_drM2UA2x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_8GPX3Gxs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_0b74NO31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_okFitmns_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_wPdczNpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fClDRAC3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ycZzfj4, 2, m, &cDelay_4ycZzfj4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqCuXZF0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_okFitmns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_wPdczNpJ, 0, m, &hTable_wPdczNpJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OMcuQlUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_0b74NO31_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kF0mRabj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_wPdczNpJ, 0, m, &hTable_wPdczNpJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_FqCuXZF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ycZzfj4, 0, m, &cDelay_4ycZzfj4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fClDRAC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WgZYbQEF, 2, m, &cDelay_WgZYbQEF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8GPX3Gxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CRXpaWLf, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_DfdQmBkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zbCZpUpa_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zbCZpUpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gq1Ja6Sz_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rAaXvMc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rAaXvMc8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1CzzuPvh, 0, m, &cDelay_1CzzuPvh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rAaXvMc8, 0, m, &cDelay_rAaXvMc8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tbiNjGpj, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_1CzzuPvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1CzzuPvh, m);
  cMsg_69Lw4Z57_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_mODoxFhV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_TXmhoUCg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_DPBJTSJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A0xnXgHp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_5A2r9Zyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tjgKFnLq_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rAaXvMc8, 2, m, &cDelay_rAaXvMc8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RJnJdpYb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A0xnXgHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5A2r9Zyx, 0, m, &hTable_5A2r9Zyx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gq1Ja6Sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_DPBJTSJt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_69Lw4Z57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5A2r9Zyx, 0, m, &hTable_5A2r9Zyx_sendMessage);
}

void Heavy_ChaffVerb::cCast_RJnJdpYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rAaXvMc8, 0, m, &cDelay_rAaXvMc8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tjgKFnLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_1CzzuPvh, 2, m, &cDelay_1CzzuPvh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TXmhoUCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tbiNjGpj, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_RztTIQCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Nz9Ago7c_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Nz9Ago7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6AaX4dmd_sendMessage);
}

void Heavy_ChaffVerb::cDelay_502lqRWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_502lqRWw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHYfMRRV, 0, m, &cDelay_MHYfMRRV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_502lqRWw, 0, m, &cDelay_502lqRWw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fMDwnoyS, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_MHYfMRRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MHYfMRRV, m);
  cMsg_NdKcC07g_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_pP83l3Yj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_YX1SOjOq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_KX35phux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i54AzSFW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_TKbRAdvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9uT7zqSE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_502lqRWw, 2, m, &cDelay_502lqRWw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VxQVajnA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_i54AzSFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TKbRAdvQ, 0, m, &hTable_TKbRAdvQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6AaX4dmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_KX35phux_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NdKcC07g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TKbRAdvQ, 0, m, &hTable_TKbRAdvQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_VxQVajnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_502lqRWw, 0, m, &cDelay_502lqRWw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9uT7zqSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHYfMRRV, 2, m, &cDelay_MHYfMRRV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YX1SOjOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fMDwnoyS, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_aNWGerEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7x8mQgiT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7x8mQgiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TwYwm2eP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_hN8EeENw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hN8EeENw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jVxaXvU0, 0, m, &cDelay_jVxaXvU0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hN8EeENw, 0, m, &cDelay_hN8EeENw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_f2jBEpEb, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_jVxaXvU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jVxaXvU0, m);
  cMsg_q8K9L7hW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_CSuQ8xFJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_QcyBETQL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_hnReGYTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uSLF1vGj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_7YuvHw7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_al8YuVpe_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hN8EeENw, 2, m, &cDelay_hN8EeENw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1vFpnTZV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uSLF1vGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_7YuvHw7R, 0, m, &hTable_7YuvHw7R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TwYwm2eP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_hnReGYTG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_q8K9L7hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_7YuvHw7R, 0, m, &hTable_7YuvHw7R_sendMessage);
}

void Heavy_ChaffVerb::cCast_1vFpnTZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hN8EeENw, 0, m, &cDelay_hN8EeENw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_al8YuVpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_jVxaXvU0, 2, m, &cDelay_jVxaXvU0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QcyBETQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_f2jBEpEb, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_K4PnQdXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_lRHeRMcZ, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_3YqwzeYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_Ezfv51Su, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_zvL0pmQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Ev2ShP6O_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ev2ShP6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_m1KgPrbv_sendMessage);
}

void Heavy_ChaffVerb::cVar_HSlGCHA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EMt4Vyzp, HV_BINOP_MULTIPLY, 0, m, &cBinop_EMt4Vyzp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4TgKCkTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vTRbwWhD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vTRbwWhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yVv2TF1z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_EMt4Vyzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vOzzieBv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qJBNjWFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EMt4Vyzp, HV_BINOP_MULTIPLY, 1, m, &cBinop_EMt4Vyzp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yVv2TF1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qJBNjWFz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vOzzieBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Z2fqK4pv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Z2fqK4pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_b6qMY8ba_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wEWJpLdz, m);
}

void Heavy_ChaffVerb::cBinop_b6qMY8ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dLE8noca, m);
}

void Heavy_ChaffVerb::cVar_F9qBmmsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_sc6FT59X_sendMessage);
}

void Heavy_ChaffVerb::cVar_AHOszjdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zvL0pmQG_sendMessage);
}

void Heavy_ChaffVerb::cVar_7r6dzwHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_MHH8fvZm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_poHZtvEi, 0, m, &cIf_poHZtvEi_sendMessage);
}

void Heavy_ChaffVerb::cVar_LKCycrEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_uOTpqZ4o_sendMessage);
}

void Heavy_ChaffVerb::cIf_poHZtvEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_exKKrtmm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_POKssBKH, 0, m, &cVar_POKssBKH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_MHH8fvZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_poHZtvEi, 1, m, &cIf_poHZtvEi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uOTpqZ4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_k9Tqh78W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_k9Tqh78W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eeqrJpuU, 0, m, &cVar_eeqrJpuU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F4hXZaeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YSu9pFWM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YSu9pFWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ntGDMCz5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_0gXpYMnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0gXpYMnE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gHlhYlC3, 0, m, &cDelay_gHlhYlC3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0gXpYMnE, 0, m, &cDelay_0gXpYMnE_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IaUKLhF8, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_gHlhYlC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gHlhYlC3, m);
  cMsg_4x3U3L9R_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_pH5nSwkS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_uo19bEj7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_wx6bMVdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8M490MLI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_tNSn6Vtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lwCBd2F2_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0gXpYMnE, 2, m, &cDelay_0gXpYMnE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8AnIZy5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8M490MLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_tNSn6Vtl, 0, m, &hTable_tNSn6Vtl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ntGDMCz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_wx6bMVdu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4x3U3L9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_tNSn6Vtl, 0, m, &hTable_tNSn6Vtl_sendMessage);
}

void Heavy_ChaffVerb::cCast_P8AnIZy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0gXpYMnE, 0, m, &cDelay_0gXpYMnE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lwCBd2F2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gHlhYlC3, 2, m, &cDelay_gHlhYlC3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uo19bEj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IaUKLhF8, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_aknAYwMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cshdMLNj, HV_BINOP_SUBTRACT, 0, m, &cBinop_cshdMLNj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zEaDoJap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YFocQdfc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YFocQdfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FJ8u6v79_sendMessage);
}

void Heavy_ChaffVerb::cVar_EefoUigE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4OI6NN2W_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_zxS67NUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zxS67NUe, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bvprG8Eq, 0, m, &cDelay_bvprG8Eq_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_md9W2lHD, 0, m, &sTabread_md9W2lHD_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bvprG8Eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bvprG8Eq, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_md9W2lHD, 0, m, &sTabread_md9W2lHD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bvprG8Eq, 0, m, &cDelay_bvprG8Eq_sendMessage);
}

void Heavy_ChaffVerb::sTabread_md9W2lHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_HKzwwybt, HV_BINOP_SUBTRACT, 0, m, &cBinop_HKzwwybt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_HnCpE2GK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RBcDn6UE, HV_BINOP_MAX, 0, m, &cBinop_RBcDn6UE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FJ8u6v79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HnCpE2GK, HV_BINOP_MULTIPLY, 0, m, &cBinop_HnCpE2GK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cshdMLNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x97nqSUK_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_md9W2lHD, 0, m, &sTabread_md9W2lHD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5egw6d0x_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pGK9kJfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HKzwwybt, HV_BINOP_SUBTRACT, 1, m, &cBinop_HKzwwybt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bvprG8Eq, 2, m, &cDelay_bvprG8Eq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4OI6NN2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pGK9kJfV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_x97nqSUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zxS67NUe, 0, m, &cDelay_zxS67NUe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bvprG8Eq, 0, m, &cDelay_bvprG8Eq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B8Or1WnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_RBcDn6UE, HV_BINOP_MAX, 1, m, &cBinop_RBcDn6UE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RBcDn6UE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cshdMLNj, HV_BINOP_SUBTRACT, 1, m, &cBinop_cshdMLNj_sendMessage);
}

void Heavy_ChaffVerb::cCast_5egw6d0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zxS67NUe, 0, m, &cDelay_zxS67NUe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WJPMFlFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zxS67NUe, 2, m, &cDelay_zxS67NUe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HKzwwybt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WJPMFlFB_sendMessage);
}

void Heavy_ChaffVerb::cCast_l2o3cZTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EefoUigE, 0, m, &cVar_EefoUigE_sendMessage);
  cMsg_zEaDoJap_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_aknAYwMb, 0, m, &cTabhead_aknAYwMb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zfSubXr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xHuUEkXr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xHuUEkXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4s1WmBgp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_7D0NBdb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7D0NBdb5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9CqeH8rM, 0, m, &cDelay_9CqeH8rM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7D0NBdb5, 0, m, &cDelay_7D0NBdb5_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_uJNO9xsm, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_9CqeH8rM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9CqeH8rM, m);
  cMsg_JPR9LaQ6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_dQFDMpU0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Sn52Ei64_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_7TucOsZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SeyC9v8f_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_MGugfUR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ebYX0oAK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7D0NBdb5, 2, m, &cDelay_7D0NBdb5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VR4d3dEz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SeyC9v8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_MGugfUR6, 0, m, &hTable_MGugfUR6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4s1WmBgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_7TucOsZh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JPR9LaQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_MGugfUR6, 0, m, &hTable_MGugfUR6_sendMessage);
}

void Heavy_ChaffVerb::cCast_VR4d3dEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7D0NBdb5, 0, m, &cDelay_7D0NBdb5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ebYX0oAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9CqeH8rM, 2, m, &cDelay_9CqeH8rM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Sn52Ei64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_uJNO9xsm, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_iXy9DCvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WNRhtGXf, HV_BINOP_SUBTRACT, 0, m, &cBinop_WNRhtGXf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1ddP1Vy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VOQLUouz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VOQLUouz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Dvt3jHd4_sendMessage);
}

void Heavy_ChaffVerb::cVar_zlj8FHVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BLzCNKyY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_h6IeY1oP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h6IeY1oP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tY4ccei7, 0, m, &cDelay_tY4ccei7_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_frKbON3F, 0, m, &sTabread_frKbON3F_sendMessage);
}

void Heavy_ChaffVerb::cDelay_tY4ccei7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tY4ccei7, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_frKbON3F, 0, m, &sTabread_frKbON3F_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tY4ccei7, 0, m, &cDelay_tY4ccei7_sendMessage);
}

void Heavy_ChaffVerb::sTabread_frKbON3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_MmSlofXr, HV_BINOP_SUBTRACT, 0, m, &cBinop_MmSlofXr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_AtQLUW4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3s4DzZnl, HV_BINOP_MAX, 0, m, &cBinop_3s4DzZnl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Dvt3jHd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AtQLUW4p, HV_BINOP_MULTIPLY, 0, m, &cBinop_AtQLUW4p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WNRhtGXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MMwRTkq1_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_frKbON3F, 0, m, &sTabread_frKbON3F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_usJd83vV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_gfYY7BGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MmSlofXr, HV_BINOP_SUBTRACT, 1, m, &cBinop_MmSlofXr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tY4ccei7, 2, m, &cDelay_tY4ccei7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BLzCNKyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gfYY7BGX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MMwRTkq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_h6IeY1oP, 0, m, &cDelay_h6IeY1oP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tY4ccei7, 0, m, &cDelay_tY4ccei7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FS1Hwuk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_3s4DzZnl, HV_BINOP_MAX, 1, m, &cBinop_3s4DzZnl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3s4DzZnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WNRhtGXf, HV_BINOP_SUBTRACT, 1, m, &cBinop_WNRhtGXf_sendMessage);
}

void Heavy_ChaffVerb::cCast_usJd83vV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h6IeY1oP, 0, m, &cDelay_h6IeY1oP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QHSaXxp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h6IeY1oP, 2, m, &cDelay_h6IeY1oP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MmSlofXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QHSaXxp8_sendMessage);
}

void Heavy_ChaffVerb::cCast_9zsN1J3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zlj8FHVf, 0, m, &cVar_zlj8FHVf_sendMessage);
  cMsg_1ddP1Vy9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iXy9DCvI, 0, m, &cTabhead_iXy9DCvI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_O26RDPFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JkjeJjpf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JkjeJjpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1bbqz5VD_sendMessage);
}

void Heavy_ChaffVerb::cDelay_VbLDURlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VbLDURlZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wfw4TEHM, 0, m, &cDelay_wfw4TEHM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VbLDURlZ, 0, m, &cDelay_VbLDURlZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fOjMITgU, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_wfw4TEHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wfw4TEHM, m);
  cMsg_weo6ZaCy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ikisInRg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_AfixM86g_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Odz65GT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fanAAlZu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_emDYDVwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F2oLu150_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VbLDURlZ, 2, m, &cDelay_VbLDURlZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nUrq9xX8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fanAAlZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_emDYDVwz, 0, m, &hTable_emDYDVwz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1bbqz5VD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_Odz65GT9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_weo6ZaCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_emDYDVwz, 0, m, &hTable_emDYDVwz_sendMessage);
}

void Heavy_ChaffVerb::cCast_nUrq9xX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VbLDURlZ, 0, m, &cDelay_VbLDURlZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F2oLu150_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wfw4TEHM, 2, m, &cDelay_wfw4TEHM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AfixM86g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fOjMITgU, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_m6Etjp1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9lyRiT9l, HV_BINOP_SUBTRACT, 0, m, &cBinop_9lyRiT9l_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vLMuInHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zPYmNGED_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zPYmNGED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_St1CHJh0_sendMessage);
}

void Heavy_ChaffVerb::cVar_mqBwZ7gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uFIqXYGh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_3Ips83n2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3Ips83n2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cpfn0VK0, 0, m, &cDelay_Cpfn0VK0_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EogYwzgO, 0, m, &sTabread_EogYwzgO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Cpfn0VK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cpfn0VK0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EogYwzgO, 0, m, &sTabread_EogYwzgO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cpfn0VK0, 0, m, &cDelay_Cpfn0VK0_sendMessage);
}

void Heavy_ChaffVerb::sTabread_EogYwzgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uG25ajUj, HV_BINOP_SUBTRACT, 0, m, &cBinop_uG25ajUj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_V98jRqTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Q1TFB9U, HV_BINOP_MAX, 0, m, &cBinop_2Q1TFB9U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_St1CHJh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V98jRqTH, HV_BINOP_MULTIPLY, 0, m, &cBinop_V98jRqTH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9lyRiT9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kv4fnzDO_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EogYwzgO, 0, m, &sTabread_EogYwzgO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WUNmEWHT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_gWNePGPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uG25ajUj, HV_BINOP_SUBTRACT, 1, m, &cBinop_uG25ajUj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cpfn0VK0, 2, m, &cDelay_Cpfn0VK0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uFIqXYGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gWNePGPh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kv4fnzDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3Ips83n2, 0, m, &cDelay_3Ips83n2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cpfn0VK0, 0, m, &cDelay_Cpfn0VK0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xSdVqRAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Q1TFB9U, HV_BINOP_MAX, 1, m, &cBinop_2Q1TFB9U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2Q1TFB9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9lyRiT9l, HV_BINOP_SUBTRACT, 1, m, &cBinop_9lyRiT9l_sendMessage);
}

void Heavy_ChaffVerb::cCast_WUNmEWHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3Ips83n2, 0, m, &cDelay_3Ips83n2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wgzYdmkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3Ips83n2, 2, m, &cDelay_3Ips83n2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uG25ajUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wgzYdmkm_sendMessage);
}

void Heavy_ChaffVerb::cCast_NBJ7qSHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mqBwZ7gx, 0, m, &cVar_mqBwZ7gx_sendMessage);
  cMsg_vLMuInHX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_m6Etjp1n, 0, m, &cTabhead_m6Etjp1n_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZZZmZZ2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_t5tHTRb5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_t5tHTRb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xUhMG1Lr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_eM3xHo9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eM3xHo9F, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4uJeTEIz, 0, m, &cDelay_4uJeTEIz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eM3xHo9F, 0, m, &cDelay_eM3xHo9F_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WuoAJjGa, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_4uJeTEIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4uJeTEIz, m);
  cMsg_MMffPAYZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_SZDbsAQ0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZL4ghQ2o_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_cqMmf0bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0eBWagvQ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_5tQbL0kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YuBem4qu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eM3xHo9F, 2, m, &cDelay_eM3xHo9F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hGqFJSgH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0eBWagvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5tQbL0kn, 0, m, &hTable_5tQbL0kn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xUhMG1Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_cqMmf0bl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MMffPAYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5tQbL0kn, 0, m, &hTable_5tQbL0kn_sendMessage);
}

void Heavy_ChaffVerb::cCast_hGqFJSgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eM3xHo9F, 0, m, &cDelay_eM3xHo9F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YuBem4qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4uJeTEIz, 2, m, &cDelay_4uJeTEIz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZL4ghQ2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WuoAJjGa, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_hL9s3z62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ku0MLZy6, HV_BINOP_SUBTRACT, 0, m, &cBinop_ku0MLZy6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nAC5PKiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Rpw3YgyH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Rpw3YgyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vRRImeS0_sendMessage);
}

void Heavy_ChaffVerb::cVar_iegFFako_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pIG7ycJG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_U7gXAZEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_U7gXAZEo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_na2rL4o7, 0, m, &cDelay_na2rL4o7_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1ApzqGAn, 0, m, &sTabread_1ApzqGAn_sendMessage);
}

void Heavy_ChaffVerb::cDelay_na2rL4o7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_na2rL4o7, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1ApzqGAn, 0, m, &sTabread_1ApzqGAn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_na2rL4o7, 0, m, &cDelay_na2rL4o7_sendMessage);
}

void Heavy_ChaffVerb::sTabread_1ApzqGAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XEFBhMPx, HV_BINOP_SUBTRACT, 0, m, &cBinop_XEFBhMPx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_J6KpcyON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TMC0sOHC, HV_BINOP_MAX, 0, m, &cBinop_TMC0sOHC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vRRImeS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J6KpcyON, HV_BINOP_MULTIPLY, 0, m, &cBinop_J6KpcyON_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ku0MLZy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fWPjFt1t_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1ApzqGAn, 0, m, &sTabread_1ApzqGAn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6a8Ltsax_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wIQDrjBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XEFBhMPx, HV_BINOP_SUBTRACT, 1, m, &cBinop_XEFBhMPx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_na2rL4o7, 2, m, &cDelay_na2rL4o7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pIG7ycJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wIQDrjBz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fWPjFt1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_U7gXAZEo, 0, m, &cDelay_U7gXAZEo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_na2rL4o7, 0, m, &cDelay_na2rL4o7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HgueDCvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_TMC0sOHC, HV_BINOP_MAX, 1, m, &cBinop_TMC0sOHC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TMC0sOHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ku0MLZy6, HV_BINOP_SUBTRACT, 1, m, &cBinop_ku0MLZy6_sendMessage);
}

void Heavy_ChaffVerb::cCast_6a8Ltsax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_U7gXAZEo, 0, m, &cDelay_U7gXAZEo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_55ZChlxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_U7gXAZEo, 2, m, &cDelay_U7gXAZEo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XEFBhMPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_55ZChlxL_sendMessage);
}

void Heavy_ChaffVerb::cCast_d6bKAyHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iegFFako, 0, m, &cVar_iegFFako_sendMessage);
  cMsg_nAC5PKiH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hL9s3z62, 0, m, &cTabhead_hL9s3z62_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BFd7qWMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9UpJzTrZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9UpJzTrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_F6eU2Kuk_sendMessage);
}

void Heavy_ChaffVerb::cDelay_RdQEwcJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RdQEwcJI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wr1XIBPV, 0, m, &cDelay_Wr1XIBPV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RdQEwcJI, 0, m, &cDelay_RdQEwcJI_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2yXCFzXM, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Wr1XIBPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Wr1XIBPV, m);
  cMsg_KpStpZc3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_0CfeYwwv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_c8JZ4Jg5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_K1v0ye0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f67ftqZe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Avz2hLQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JPpAz5ns_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RdQEwcJI, 2, m, &cDelay_RdQEwcJI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7UAJHV25_sendMessage);
}

void Heavy_ChaffVerb::cMsg_f67ftqZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Avz2hLQx, 0, m, &hTable_Avz2hLQx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_F6eU2Kuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_K1v0ye0Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KpStpZc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Avz2hLQx, 0, m, &hTable_Avz2hLQx_sendMessage);
}

void Heavy_ChaffVerb::cCast_7UAJHV25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RdQEwcJI, 0, m, &cDelay_RdQEwcJI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JPpAz5ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wr1XIBPV, 2, m, &cDelay_Wr1XIBPV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c8JZ4Jg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2yXCFzXM, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Z8WE4sfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ET00avC6, HV_BINOP_SUBTRACT, 0, m, &cBinop_ET00avC6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zkrcGe5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3LMv8HP9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3LMv8HP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aqX9O9Bk_sendMessage);
}

void Heavy_ChaffVerb::cVar_bRO7vB3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cSSIFoYY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_HT85cYWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HT85cYWe, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oeZCRwUD, 0, m, &cDelay_oeZCRwUD_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rY7yVUSK, 0, m, &sTabread_rY7yVUSK_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oeZCRwUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oeZCRwUD, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rY7yVUSK, 0, m, &sTabread_rY7yVUSK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oeZCRwUD, 0, m, &cDelay_oeZCRwUD_sendMessage);
}

void Heavy_ChaffVerb::sTabread_rY7yVUSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_QJwEZ21f, HV_BINOP_SUBTRACT, 0, m, &cBinop_QJwEZ21f_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_lchHwaKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHossFJC, HV_BINOP_MAX, 0, m, &cBinop_ZHossFJC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aqX9O9Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lchHwaKp, HV_BINOP_MULTIPLY, 0, m, &cBinop_lchHwaKp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ET00avC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_71SLFi9w_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rY7yVUSK, 0, m, &sTabread_rY7yVUSK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jnaj2agm_sendMessage);
}

void Heavy_ChaffVerb::cSystem_COxlzzqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJwEZ21f, HV_BINOP_SUBTRACT, 1, m, &cBinop_QJwEZ21f_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oeZCRwUD, 2, m, &cDelay_oeZCRwUD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cSSIFoYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_COxlzzqq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_71SLFi9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HT85cYWe, 0, m, &cDelay_HT85cYWe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oeZCRwUD, 0, m, &cDelay_oeZCRwUD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Rp37ym7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHossFJC, HV_BINOP_MAX, 1, m, &cBinop_ZHossFJC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZHossFJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ET00avC6, HV_BINOP_SUBTRACT, 1, m, &cBinop_ET00avC6_sendMessage);
}

void Heavy_ChaffVerb::cCast_Jnaj2agm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HT85cYWe, 0, m, &cDelay_HT85cYWe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dQFdoT6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HT85cYWe, 2, m, &cDelay_HT85cYWe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QJwEZ21f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dQFdoT6s_sendMessage);
}

void Heavy_ChaffVerb::cCast_8AvnEmYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bRO7vB3t, 0, m, &cVar_bRO7vB3t_sendMessage);
  cMsg_zkrcGe5i_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Z8WE4sfU, 0, m, &cTabhead_Z8WE4sfU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lETNTkFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5wTRpiCJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_5wTRpiCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_u6ETI3su_sendMessage);
}

void Heavy_ChaffVerb::cDelay_5EeaIJNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5EeaIJNV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AKCvJFlb, 0, m, &cDelay_AKCvJFlb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5EeaIJNV, 0, m, &cDelay_5EeaIJNV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_E5r8nFey, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_AKCvJFlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AKCvJFlb, m);
  cMsg_UgA0KcTl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_bHqc6YaO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ibQV0lLt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_oFj8SUsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j427yxXN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ToCIyopm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xLCbKBLn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5EeaIJNV, 2, m, &cDelay_5EeaIJNV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gj29PWes_sendMessage);
}

void Heavy_ChaffVerb::cMsg_j427yxXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ToCIyopm, 0, m, &hTable_ToCIyopm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u6ETI3su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_oFj8SUsR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UgA0KcTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ToCIyopm, 0, m, &hTable_ToCIyopm_sendMessage);
}

void Heavy_ChaffVerb::cCast_gj29PWes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5EeaIJNV, 0, m, &cDelay_5EeaIJNV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xLCbKBLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_AKCvJFlb, 2, m, &cDelay_AKCvJFlb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ibQV0lLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_E5r8nFey, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_6nDh6N0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FxaFlwTB, HV_BINOP_SUBTRACT, 0, m, &cBinop_FxaFlwTB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_s9HpVawm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VM5vfdZW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VM5vfdZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9GUWdxxD_sendMessage);
}

void Heavy_ChaffVerb::cVar_83kHpFj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wMpaenIt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_DkySWy7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DkySWy7V, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3w7hwfiZ, 0, m, &cDelay_3w7hwfiZ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mYYZ7gvP, 0, m, &sTabread_mYYZ7gvP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3w7hwfiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3w7hwfiZ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mYYZ7gvP, 0, m, &sTabread_mYYZ7gvP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3w7hwfiZ, 0, m, &cDelay_3w7hwfiZ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_mYYZ7gvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RyMypoWH, HV_BINOP_SUBTRACT, 0, m, &cBinop_RyMypoWH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_8Lk5ozKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z285CSYM, HV_BINOP_MAX, 0, m, &cBinop_z285CSYM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9GUWdxxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Lk5ozKv, HV_BINOP_MULTIPLY, 0, m, &cBinop_8Lk5ozKv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FxaFlwTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HMefA8e1_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mYYZ7gvP, 0, m, &sTabread_mYYZ7gvP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CsIFeJJj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kOXEPXru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RyMypoWH, HV_BINOP_SUBTRACT, 1, m, &cBinop_RyMypoWH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3w7hwfiZ, 2, m, &cDelay_3w7hwfiZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wMpaenIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kOXEPXru_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HMefA8e1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DkySWy7V, 0, m, &cDelay_DkySWy7V_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3w7hwfiZ, 0, m, &cDelay_3w7hwfiZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nS95ZjQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_z285CSYM, HV_BINOP_MAX, 1, m, &cBinop_z285CSYM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z285CSYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FxaFlwTB, HV_BINOP_SUBTRACT, 1, m, &cBinop_FxaFlwTB_sendMessage);
}

void Heavy_ChaffVerb::cCast_CsIFeJJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DkySWy7V, 0, m, &cDelay_DkySWy7V_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GpKJyUM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DkySWy7V, 2, m, &cDelay_DkySWy7V_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RyMypoWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GpKJyUM1_sendMessage);
}

void Heavy_ChaffVerb::cCast_HR7iuo9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_83kHpFj9, 0, m, &cVar_83kHpFj9_sendMessage);
  cMsg_s9HpVawm_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6nDh6N0v, 0, m, &cTabhead_6nDh6N0v_sendMessage);
}

void Heavy_ChaffVerb::cVar_POKssBKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HSlGCHA7, 0, m, &cVar_HSlGCHA7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GbTlsh7E, 0, m, &cVar_GbTlsh7E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fVuXzs52, 0, m, &cVar_fVuXzs52_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UHz1HLls, 0, m, &cVar_UHz1HLls_sendMessage);
}

void Heavy_ChaffVerb::cVar_eeqrJpuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_xFFN2IkJ_sendMessage);
}

void Heavy_ChaffVerb::cPack_GlVwqoqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_1a7Hv02L, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_GbTlsh7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYxWUfBD, HV_BINOP_MULTIPLY, 0, m, &cBinop_yYxWUfBD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lTdcDZTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_u5GBZJh4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_u5GBZJh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XB5bCoTi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_yYxWUfBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_s5BMpUzK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JmNGUXqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYxWUfBD, HV_BINOP_MULTIPLY, 1, m, &cBinop_yYxWUfBD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XB5bCoTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JmNGUXqG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s5BMpUzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DcVswJyU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DcVswJyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_20NlDdF9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MttIgxIx, m);
}

void Heavy_ChaffVerb::cBinop_20NlDdF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9hfZddUY, m);
}

void Heavy_ChaffVerb::cVar_fVuXzs52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8TIHPuUU, HV_BINOP_MULTIPLY, 0, m, &cBinop_8TIHPuUU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pK6MLld1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HTBzZRha_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HTBzZRha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2pSuOpTj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_8TIHPuUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qiarUK0k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nQzUBpC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8TIHPuUU, HV_BINOP_MULTIPLY, 1, m, &cBinop_8TIHPuUU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2pSuOpTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nQzUBpC6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qiarUK0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XtsuzYDn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XtsuzYDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pqKoES14_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_juFiOZ8o, m);
}

void Heavy_ChaffVerb::cBinop_pqKoES14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0zS2SgK0, m);
}

void Heavy_ChaffVerb::cVar_UHz1HLls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nCwwhn8, HV_BINOP_MULTIPLY, 0, m, &cBinop_5nCwwhn8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L3N5OAZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jqf78rET_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jqf78rET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8h0xV5yG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_5nCwwhn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Sq5sfbGx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RiYX2VrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nCwwhn8, HV_BINOP_MULTIPLY, 1, m, &cBinop_5nCwwhn8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8h0xV5yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RiYX2VrP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Sq5sfbGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dIFSLBHA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dIFSLBHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_upHUBXAf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_g0jqgPS0, m);
}

void Heavy_ChaffVerb::cBinop_upHUBXAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KRCeIT5E, m);
}

void Heavy_ChaffVerb::cBinop_m1KgPrbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_3YqwzeYQ, 0, m, &cPack_3YqwzeYQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_exKKrtmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_POKssBKH, 0, m, &cVar_POKssBKH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xFFN2IkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_GlVwqoqn, 0, m, &cPack_GlVwqoqn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sc6FT59X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_K4PnQdXQ, 0, m, &cPack_K4PnQdXQ_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_kmq3hgdi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_SZ1KK6GO_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_SZ1KK6GO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pFdMtrCL_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_QyU9T2L3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QyU9T2L3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QyU9T2L3, 0, m, &cDelay_QyU9T2L3_sendMessage);
  cSwitchcase_4mvOr2Ug_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_pFdMtrCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SZ1KK6GO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QyU9T2L3, 0, m, &cDelay_QyU9T2L3_sendMessage);
  cSwitchcase_4mvOr2Ug_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_zIsnKIAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X7TePXAu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_X7TePXAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qSJCm20t_sendMessage);
}

void Heavy_ChaffVerb::cVar_5FSPIk4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IduixJ1G, HV_BINOP_MULTIPLY, 0, m, &cBinop_IduixJ1G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SZ1KK6GO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QyU9T2L3, 0, m, &cDelay_QyU9T2L3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wNHUks45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QyU9T2L3, 2, m, &cDelay_QyU9T2L3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qSJCm20t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IduixJ1G, HV_BINOP_MULTIPLY, 1, m, &cBinop_IduixJ1G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IduixJ1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_wNHUks45_sendMessage);
}

void Heavy_ChaffVerb::cVar_WHXQ45N1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_JnKyS8iI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_hVA6EyMb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YyON3lLQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_DG3Qnaw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jkcx0EbM_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_yBSky8vu, 0, m, &cIf_yBSky8vu_sendMessage);
}

void Heavy_ChaffVerb::cUnop_chW1nKqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YObEr6Bo, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_YObEr6Bo_sendMessage);
}

void Heavy_ChaffVerb::cUnop_H5yAW1gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YObEr6Bo, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_YObEr6Bo_sendMessage);
}

void Heavy_ChaffVerb::cIf_yBSky8vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_H5yAW1gJ_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_chW1nKqt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_jkcx0EbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yBSky8vu, 1, m, &cIf_yBSky8vu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zmA9EANP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xpdx8RwV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Xpdx8RwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mKvqHyNq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_MtFC3sg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MtFC3sg4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ib7httWY, 0, m, &cDelay_Ib7httWY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MtFC3sg4, 0, m, &cDelay_MtFC3sg4_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1vQ6VjNe, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Ib7httWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ib7httWY, m);
  cMsg_Dhr8hoDS_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_L9cXkt2P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_twgWlZmM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_7J3uBwSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_imYs6cKh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_1XjpSzeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E2d9hPG4_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MtFC3sg4, 2, m, &cDelay_MtFC3sg4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LMtuij71_sendMessage);
}

void Heavy_ChaffVerb::cMsg_imYs6cKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_1XjpSzeq, 0, m, &hTable_1XjpSzeq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mKvqHyNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_7J3uBwSI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Dhr8hoDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_1XjpSzeq, 0, m, &hTable_1XjpSzeq_sendMessage);
}

void Heavy_ChaffVerb::cCast_LMtuij71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MtFC3sg4, 0, m, &cDelay_MtFC3sg4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_E2d9hPG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ib7httWY, 2, m, &cDelay_Ib7httWY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_twgWlZmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1vQ6VjNe, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_sX1yC4Yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAeIc8ls, HV_BINOP_SUBTRACT, 0, m, &cBinop_fAeIc8ls_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m0owYjol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2A4ZB5iW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2A4ZB5iW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tGt9XMi8_sendMessage);
}

void Heavy_ChaffVerb::cVar_Mf8ghVRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UmaOLvmC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_wokSF4Wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wokSF4Wl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PZkDYgok, 0, m, &cDelay_PZkDYgok_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Lx5Bs3di, 0, m, &sTabread_Lx5Bs3di_sendMessage);
}

void Heavy_ChaffVerb::cDelay_PZkDYgok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PZkDYgok, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Lx5Bs3di, 0, m, &sTabread_Lx5Bs3di_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PZkDYgok, 0, m, &cDelay_PZkDYgok_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Lx5Bs3di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GMatwuuu, HV_BINOP_SUBTRACT, 0, m, &cBinop_GMatwuuu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_uzE64LDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLTP6G7n, HV_BINOP_MAX, 0, m, &cBinop_SLTP6G7n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tGt9XMi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uzE64LDk, HV_BINOP_MULTIPLY, 0, m, &cBinop_uzE64LDk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fAeIc8ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YaJ2pa5k_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Lx5Bs3di, 0, m, &sTabread_Lx5Bs3di_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HpZJYeU8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wBVd5YL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GMatwuuu, HV_BINOP_SUBTRACT, 1, m, &cBinop_GMatwuuu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PZkDYgok, 2, m, &cDelay_PZkDYgok_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UmaOLvmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wBVd5YL3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YaJ2pa5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wokSF4Wl, 0, m, &cDelay_wokSF4Wl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PZkDYgok, 0, m, &cDelay_PZkDYgok_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EjYnU63C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLTP6G7n, HV_BINOP_MAX, 1, m, &cBinop_SLTP6G7n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SLTP6G7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAeIc8ls, HV_BINOP_SUBTRACT, 1, m, &cBinop_fAeIc8ls_sendMessage);
}

void Heavy_ChaffVerb::cCast_HpZJYeU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wokSF4Wl, 0, m, &cDelay_wokSF4Wl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Gsy6J4bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wokSF4Wl, 2, m, &cDelay_wokSF4Wl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GMatwuuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Gsy6J4bQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_Bc7uyE7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mf8ghVRW, 0, m, &cVar_Mf8ghVRW_sendMessage);
  cMsg_m0owYjol_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sX1yC4Yi, 0, m, &cTabhead_sX1yC4Yi_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_VjLpngWL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gn3ROFWL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_gn3ROFWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A4Zz6XDz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_XT5xndzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jaxSsEro, HV_BINOP_ADD, 0, m, &cBinop_jaxSsEro_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_xVieuHoW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P9IL8cuE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_P9IL8cuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iljG9mZr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_bvxNzdgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WtN5oQc9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FyUZw0Oq_sendMessage);
}

void Heavy_ChaffVerb::cVar_TE6yMAFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UmJpRQmH, 0, m, &cVar_UmJpRQmH_sendMessage);
}

void Heavy_ChaffVerb::cVar_UmJpRQmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jjCntwxR, HV_BINOP_ADD, 0, m, &cBinop_jjCntwxR_sendMessage);
}

void Heavy_ChaffVerb::cVar_fLJ1G8Dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htC4fmL2, HV_BINOP_ADD, 0, m, &cBinop_htC4fmL2_sendMessage);
}

void Heavy_ChaffVerb::cVar_qeIAI8zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FnKuJIBK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_n5bkwcMp, 0, m, &cIf_n5bkwcMp_sendMessage);
}

void Heavy_ChaffVerb::cUnop_ttj0nwVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htC4fmL2, HV_BINOP_ADD, 1, m, &cBinop_htC4fmL2_sendMessage);
}

void Heavy_ChaffVerb::cUnop_agyefumz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htC4fmL2, HV_BINOP_ADD, 1, m, &cBinop_htC4fmL2_sendMessage);
}

void Heavy_ChaffVerb::cIf_n5bkwcMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_agyefumz_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_ttj0nwVq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_FnKuJIBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n5bkwcMp, 1, m, &cIf_n5bkwcMp_sendMessage);
}

void Heavy_ChaffVerb::cVar_VYz93BPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4VxPk6DZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_A2RTTro3, 0, m, &cIf_A2RTTro3_sendMessage);
}

void Heavy_ChaffVerb::cUnop_jgnp9dSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SY1o8nP3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_C8GZyRpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SY1o8nP3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_A2RTTro3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_C8GZyRpJ_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_jgnp9dSu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_4VxPk6DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A2RTTro3, 1, m, &cIf_A2RTTro3_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_SY1o8nP3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XBoxBlK0, 0, m, &cSlice_XBoxBlK0_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PfMGu1wg, 0, m, &cSlice_PfMGu1wg_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_avc8ujFp_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GVvY0EOm_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_XBoxBlK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_7QnUSpqE, 0, m, &cVar_7QnUSpqE_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_7QnUSpqE, 0, m, &cVar_7QnUSpqE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_PfMGu1wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_zG3kG6ph, HV_BINOP_NEQ, 1, m, &cBinop_zG3kG6ph_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_7QnUSpqE, 1, m, &cVar_7QnUSpqE_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_zG3kG6ph, HV_BINOP_NEQ, 1, m, &cBinop_zG3kG6ph_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_7QnUSpqE, 1, m, &cVar_7QnUSpqE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_7QnUSpqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KZS9HhG0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJMKVXyO_sendMessage);
}

void Heavy_ChaffVerb::cIf_X40IJkea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VtIECSFJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PZ3dOUOu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_VtIECSFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zG3kG6ph, HV_BINOP_NEQ, 1, m, &cBinop_zG3kG6ph_sendMessage);
}

void Heavy_ChaffVerb::cCast_PZ3dOUOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7QnUSpqE, 0, m, &cVar_7QnUSpqE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zG3kG6ph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X40IJkea, 1, m, &cIf_X40IJkea_sendMessage);
}

void Heavy_ChaffVerb::cCast_GVvY0EOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X40IJkea, 0, m, &cIf_X40IJkea_sendMessage);
}

void Heavy_ChaffVerb::cCast_avc8ujFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zG3kG6ph, HV_BINOP_NEQ, 0, m, &cBinop_zG3kG6ph_sendMessage);
}

void Heavy_ChaffVerb::cIf_fJYHQjYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TE6yMAFI, 0, m, &cVar_TE6yMAFI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_9wriYu8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_fJYHQjYf, 0, m, &cIf_fJYHQjYf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_vkCQZ1rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_fJYHQjYf, 0, m, &cIf_fJYHQjYf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_hX6bEGqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_fJYHQjYf, 0, m, &cIf_fJYHQjYf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_1jxL0xft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_bvxNzdgx, 0, m, &cVar_bvxNzdgx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_ZCfKQ4v6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fLJ1G8Dn, 0, m, &cVar_fLJ1G8Dn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0EYrv1rN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9wriYu8V, 1, m, &cIf_9wriYu8V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dNewLAvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_hX6bEGqo, 1, m, &cIf_hX6bEGqo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_e4C2itZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9wriYu8V, 1, m, &cIf_9wriYu8V_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vkCQZ1rg, 1, m, &cIf_vkCQZ1rg_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_hX6bEGqo, 1, m, &cIf_hX6bEGqo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_B0Xmw2qN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XT5xndzG, 0, m, &cVar_XT5xndzG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tH07Ncba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_B0Xmw2qN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iljG9mZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_bvxNzdgx, 0, m, &cVar_bvxNzdgx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YObEr6Bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8pmQVdbu, HV_BINOP_MULTIPLY, 0, m, &cBinop_8pmQVdbu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YyON3lLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YObEr6Bo, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_YObEr6Bo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nWjUTx6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vkCQZ1rg, 1, m, &cIf_vkCQZ1rg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_htC4fmL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bZJTyyXS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lnURvqF9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hdGo7jCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UWMMT0e2, 0, m, &cVar_UWMMT0e2_sendMessage);
}

void Heavy_ChaffVerb::cCast_bZJTyyXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hdGo7jCx, HV_BINOP_ADD, 1, m, &cBinop_hdGo7jCx_sendMessage);
}

void Heavy_ChaffVerb::cCast_lnURvqF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TE6yMAFI, 0, m, &cVar_TE6yMAFI_sendMessage);
}

void Heavy_ChaffVerb::cCast_VJMKVXyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_b6vx3HyZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_KZS9HhG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e4C2itZY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_CPBSaMbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AHOszjdX, 0, m, &cVar_AHOszjdX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8pmQVdbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vkCQZ1rg, 0, m, &cIf_vkCQZ1rg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KkFLowWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hX6bEGqo, 0, m, &cIf_hX6bEGqo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TOxUo8qB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_DO3V3mTH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_KkFLowWC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JnKyS8iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_SNgSt2KJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SNgSt2KJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TOxUo8qB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hVA6EyMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WHXQ45N1, 1, m, &cVar_WHXQ45N1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4pFQ3Cfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U9g3Nsw1, 0, m, &cVar_U9g3Nsw1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GuTABrHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5FSPIk4T, 0, m, &cVar_5FSPIk4T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A4Zz6XDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TE6yMAFI, 0, m, &cVar_TE6yMAFI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jaxSsEro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3AVeJRA9, HV_BINOP_MULTIPLY, 0, m, &cBinop_3AVeJRA9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3AVeJRA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1jxL0xft, 0, m, &cIf_1jxL0xft_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VltMNnFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hdGo7jCx, HV_BINOP_ADD, 0, m, &cBinop_hdGo7jCx_sendMessage);
}

void Heavy_ChaffVerb::cCast_FyUZw0Oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TE6yMAFI, 0, m, &cVar_TE6yMAFI_sendMessage);
}

void Heavy_ChaffVerb::cCast_WtN5oQc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VltMNnFU, HV_BINOP_ADD, 1, m, &cBinop_VltMNnFU_sendMessage);
}

void Heavy_ChaffVerb::cCast_oJx852qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fJYHQjYf, 1, m, &cIf_fJYHQjYf_sendMessage);
}

void Heavy_ChaffVerb::cCast_bS1pKTow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VjLpngWL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_sWglARYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3AVeJRA9, HV_BINOP_MULTIPLY, 1, m, &cBinop_3AVeJRA9_sendMessage);
}

void Heavy_ChaffVerb::cCast_TaN0frUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XT5xndzG, 0, m, &cVar_XT5xndzG_sendMessage);
}

void Heavy_ChaffVerb::cCast_kffdjamT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1jxL0xft, 1, m, &cIf_1jxL0xft_sendMessage);
}

void Heavy_ChaffVerb::cCast_YZ65ZF4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xVieuHoW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_OiQZpP4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jaxSsEro, HV_BINOP_ADD, 1, m, &cBinop_jaxSsEro_sendMessage);
}

void Heavy_ChaffVerb::cCast_rGQcI1AT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XT5xndzG, 0, m, &cVar_XT5xndzG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Dh9ifyfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VltMNnFU, HV_BINOP_ADD, 0, m, &cBinop_VltMNnFU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jjCntwxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dh9ifyfo, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dh9ifyfo_sendMessage);
}

void Heavy_ChaffVerb::cCast_CFlBZ133_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dh9ifyfo, HV_BINOP_MULTIPLY, 1, m, &cBinop_Dh9ifyfo_sendMessage);
}

void Heavy_ChaffVerb::cCast_JTuEwNP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TE6yMAFI, 0, m, &cVar_TE6yMAFI_sendMessage);
}

void Heavy_ChaffVerb::cCast_KLEv1yVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TE6yMAFI, 0, m, &cVar_TE6yMAFI_sendMessage);
}

void Heavy_ChaffVerb::cCast_V9OrX3Zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jjCntwxR, HV_BINOP_ADD, 1, m, &cBinop_jjCntwxR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vBrDNjDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KZS9HhG0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJMKVXyO_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ro4ekVBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F4hXZaeY_sendMessage(_c, 0, m);
  cMsg_zfSubXr6_sendMessage(_c, 0, m);
  cMsg_O26RDPFX_sendMessage(_c, 0, m);
  cMsg_ZZZmZZ2I_sendMessage(_c, 0, m);
  cMsg_BFd7qWMp_sendMessage(_c, 0, m);
  cMsg_lETNTkFH_sendMessage(_c, 0, m);
  cMsg_oZSr7Hb6_sendMessage(_c, 0, m);
  cMsg_yCZswnsP_sendMessage(_c, 0, m);
  cMsg_DfdQmBkA_sendMessage(_c, 0, m);
  cMsg_RztTIQCP_sendMessage(_c, 0, m);
  cMsg_aNWGerEj_sendMessage(_c, 0, m);
  cMsg_4TgKCkTw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HSlGCHA7, 0, m, &cVar_HSlGCHA7_sendMessage);
  cMsg_lTdcDZTA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GbTlsh7E, 0, m, &cVar_GbTlsh7E_sendMessage);
  cMsg_pK6MLld1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fVuXzs52, 0, m, &cVar_fVuXzs52_sendMessage);
  cMsg_L3N5OAZL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_UHz1HLls, 0, m, &cVar_UHz1HLls_sendMessage);
  cMsg_7A6SB9av_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZhRtlPuk, 0, m, &cVar_ZhRtlPuk_sendMessage);
  cMsg_yiOritOE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_U9g3Nsw1, 0, m, &cVar_U9g3Nsw1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F9qBmmsd, 0, m, &cVar_F9qBmmsd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AHOszjdX, 0, m, &cVar_AHOszjdX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7r6dzwHN, 0, m, &cVar_7r6dzwHN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LKCycrEt, 0, m, &cVar_LKCycrEt_sendMessage);
  cMsg_zIsnKIAq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5FSPIk4T, 0, m, &cVar_5FSPIk4T_sendMessage);
  cMsg_zmA9EANP_sendMessage(_c, 0, m);
  cSwitchcase_SeI6HxYr_onMessage(_c, NULL, 0, m, NULL);
  cMsg_A4Zz6XDz_sendMessage(_c, 0, m);
  cMsg_vBrDNjDc_sendMessage(_c, 0, m);
  cMsg_iljG9mZr_sendMessage(_c, 0, m);
  cSwitchcase_kmq3hgdi_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_QyLFhk7I, 0, m, &cVar_QyLFhk7I_sendMessage);
  cMsg_jNN6ubuS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sxHvW3Pk, 0, m, &cVar_sxHvW3Pk_sendMessage);
  cMsg_qSD6jZ09_sendMessage(_c, 0, m);
  cMsg_NlcBv8Ke_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HkjIulP6, 0, m, &cVar_HkjIulP6_sendMessage);
  cMsg_pVy2P2Uf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_EnArtQpq, 0, m, &cTabhead_EnArtQpq_sendMessage);
  cMsg_FPFmKDaJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SHypic6p, 0, m, &cVar_SHypic6p_sendMessage);
  cMsg_86xi66Xw_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RGUU2kwj, 0, m, &cTabhead_RGUU2kwj_sendMessage);
  cMsg_EcdDd8Bd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_F5FHf6gp, 0, m, &cVar_F5FHf6gp_sendMessage);
  cMsg_uvmjNcu1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wx7xKHdW, 0, m, &cTabhead_wx7xKHdW_sendMessage);
  cMsg_IjtQSA3l_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_60d20ORg, 0, m, &cVar_60d20ORg_sendMessage);
  cMsg_rFfu09ED_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7ca0893V, 0, m, &cTabhead_7ca0893V_sendMessage);
  cMsg_B8Or1WnK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EefoUigE, 0, m, &cVar_EefoUigE_sendMessage);
  cMsg_zEaDoJap_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_aknAYwMb, 0, m, &cTabhead_aknAYwMb_sendMessage);
  cMsg_FS1Hwuk9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zlj8FHVf, 0, m, &cVar_zlj8FHVf_sendMessage);
  cMsg_1ddP1Vy9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iXy9DCvI, 0, m, &cTabhead_iXy9DCvI_sendMessage);
  cMsg_xSdVqRAv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mqBwZ7gx, 0, m, &cVar_mqBwZ7gx_sendMessage);
  cMsg_vLMuInHX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_m6Etjp1n, 0, m, &cTabhead_m6Etjp1n_sendMessage);
  cMsg_HgueDCvu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iegFFako, 0, m, &cVar_iegFFako_sendMessage);
  cMsg_nAC5PKiH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hL9s3z62, 0, m, &cTabhead_hL9s3z62_sendMessage);
  cMsg_Rp37ym7s_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bRO7vB3t, 0, m, &cVar_bRO7vB3t_sendMessage);
  cMsg_zkrcGe5i_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Z8WE4sfU, 0, m, &cTabhead_Z8WE4sfU_sendMessage);
  cMsg_nS95ZjQS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_83kHpFj9, 0, m, &cVar_83kHpFj9_sendMessage);
  cMsg_s9HpVawm_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6nDh6N0v, 0, m, &cTabhead_6nDh6N0v_sendMessage);
  cMsg_EjYnU63C_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Mf8ghVRW, 0, m, &cVar_Mf8ghVRW_sendMessage);
  cMsg_m0owYjol_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sX1yC4Yi, 0, m, &cTabhead_sX1yC4Yi_sendMessage);
}

void Heavy_ChaffVerb::cReceive_T6Jr708P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_4pFQ3Cfh_sendMessage);
}

void Heavy_ChaffVerb::cReceive_vmRG0h4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VYz93BPg, 0, m, &cVar_VYz93BPg_sendMessage);
}

void Heavy_ChaffVerb::cReceive_EllY8nDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DG3Qnaw3, 0, m, &cVar_DG3Qnaw3_sendMessage);
}

void Heavy_ChaffVerb::cReceive_AFW90A92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8pmQVdbu, HV_BINOP_MULTIPLY, 1, m, &cBinop_8pmQVdbu_sendMessage);
}

void Heavy_ChaffVerb::cReceive_91lhiHbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9OrX3Zk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KLEv1yVj_sendMessage);
}

void Heavy_ChaffVerb::cReceive_qXdky84I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CFlBZ133_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JTuEwNP1_sendMessage);
}

void Heavy_ChaffVerb::cReceive_WRiik0Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fLJ1G8Dn, 0, m, &cVar_fLJ1G8Dn_sendMessage);
}

void Heavy_ChaffVerb::cReceive_1LVkPoXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZCfKQ4v6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qeIAI8zw, 0, m, &cVar_qeIAI8zw_sendMessage);
}

void Heavy_ChaffVerb::cReceive_6XGFo1Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_GuTABrHs_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ECxQXQ5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OiQZpP4b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rGQcI1AT_sendMessage);
}

void Heavy_ChaffVerb::cReceive_J0hSlsEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sWglARYE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TaN0frUW_sendMessage);
}

void Heavy_ChaffVerb::cReceive_yUxrBDcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kffdjamT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YZ65ZF4r_sendMessage);
}

void Heavy_ChaffVerb::cReceive_gp8Ta2RC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_C26mOGyy, m);
}

void Heavy_ChaffVerb::cReceive_uYvPOAq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9aSE8m2S, m);
}

void Heavy_ChaffVerb::cReceive_5ZpXWD4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F9qBmmsd, 0, m, &cVar_F9qBmmsd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Bux2lCNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_CPBSaMbL_sendMessage);
}

void Heavy_ChaffVerb::cReceive_2KegU7qJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CNGTiPGD, 0, m, &cVar_CNGTiPGD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_sG45Gr5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PzCwzUWc, 0, m, &cVar_PzCwzUWc_sendMessage);
}

void Heavy_ChaffVerb::cReceive_QnS0u8yf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZhRtlPuk, 0, m, &cVar_ZhRtlPuk_sendMessage);
}

void Heavy_ChaffVerb::cReceive_aYN5EBXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AJhsVcAI, m);
}

void Heavy_ChaffVerb::cReceive_edWEiymq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z5SnoerC, m);
}

void Heavy_ChaffVerb::cReceive_0E3gQzdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uzE64LDk, HV_BINOP_MULTIPLY, 1, m, &cBinop_uzE64LDk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bc7uyE7U_sendMessage);
}

void Heavy_ChaffVerb::cReceive_9xfmKe1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oJx852qo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bS1pKTow_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_dzgHu6BW, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_hUAIaXYQ, VOf(Bf4));
    __hv_line_f(&sLine_rvsqBg5L, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_palhez3K, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Bk2mIowD, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_aUxx8GwO, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_2ISjb7KL, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_1vUeBqrD, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_xXLWRIvO, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_bmEa0HnT, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_UOT9j2j3, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_68YGmFvT, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_CYBhd4ci, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_cYpoUHYw, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_fcyAYF4R, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_WTuF4Gkk, VIf(I0));
    __hv_varread_f(&sVarf_rFwviVv3, VOf(Bf2));
    __hv_rpole_f(&sRPole_wYz5cVrI, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_EdfxeXAJ, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Ov7f08aZ, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_AJhsVcAI, VOf(Bf1));
    __hv_tabread_f(&sTabread_Lx5Bs3di, VOf(Bf5));
    __hv_varread_f(&sVarf_Z5SnoerC, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_1vQ6VjNe, VIf(Bf9));
    __hv_varread_f(&sVarf_9aSE8m2S, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_PDe0HwNj, VOf(Bf9));
    __hv_varread_f(&sVarf_wEWJpLdz, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_dLE8noca, VOf(Bf2));
    __hv_rpole_f(&sRPole_pfJJGFwL, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_1a7Hv02L, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_Ezfv51Su, VOf(Bf2));
    __hv_tabread_f(&sTabread_md9W2lHD, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_frKbON3F, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_EogYwzgO, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_1ApzqGAn, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_mYYZ7gvP, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_rY7yVUSK, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_IaUKLhF8, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_uJNO9xsm, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_fOjMITgU, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_WuoAJjGa, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_2yXCFzXM, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_E5r8nFey, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_IzrpiWte, VOf(Bf9));
    __hv_varread_f(&sVarf_MttIgxIx, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_9hfZddUY, VOf(Bf3));
    __hv_rpole_f(&sRPole_hvV9Sj9O, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_qc2b87oB, VOf(Bf3));
    __hv_varread_f(&sVarf_juFiOZ8o, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_0zS2SgK0, VOf(Bf12));
    __hv_rpole_f(&sRPole_sjpdBdLw, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_N8FJrk2P, VOf(Bf12));
    __hv_varread_f(&sVarf_g0jqgPS0, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_KRCeIT5E, VOf(Bf11));
    __hv_rpole_f(&sRPole_Mwq1JUPV, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_CRXpaWLf, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_tbiNjGpj, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_fMDwnoyS, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_f2jBEpEb, VIf(Bf11));
    __hv_line_f(&sLine_lRHeRMcZ, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_C26mOGyy, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
